/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 06844
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1985
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\06844-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cigtry    91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW' 95='(95) BAD DATA' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 91='(91) NEVER USED CIGARETTES' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED CIGARETTES' ;
  VALUE avcig     1='(1) Less than one cigarette a day'
                  2='(2) One to five cigarettes a day'
                  3='(3) About 1/2 pack a day (6-15 cigarettes)'
                  4='(4) About a pack a day (16-25 cigarettes)'
                  5='(5) About 1 1/2 packs a day (26-35 cigarettes)'
                  6='(6) About 2 packs or more a day (over 35 cigarettes)'
                  91='(91) NEVER USED CIGARETTES'
                  93='(93) HAS NOT SMOKED IN THE PAST 30 DAYS' 94='(94) DONT KNOW' ;
  VALUE cigint    1='(1) Years' 2='(2) Months' 3='(3) Weeks' 91='(91) NEVER USED CIGARETTES'
                  93='(93) HAS NOT SMOKED CIGARETTES IN THE PAST 30 DAYS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtime   91='(91) NEVER USED CIGARETTES'
                  93='(93) HAS NOT SMOKED CIGARETTES IN THE PAST 30 DAYS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    91='(91) NEVER USED CIGARETTES'
                  93='(93) NEVER SMOKED CIGARETTES DAILY' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigyrs    0='(0) Less than one year' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (CIGAGE = 93)' ;
  VALUE packs     1='(1) One to five cigarettes a day'
                  2='(2) About 1/2 pack a day (6-15 cigarettes)'
                  3='(3) About a pack a day (16-25 cigarettes)'
                  4='(4) About 1 1/2 packs a day (26-35 cigarettes)'
                  5='(5) About 2 packs or more a day (over 35 cigarettes)'
                  6='(6) Smokes cigars only' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (CIGAGE = 93)' ;
  VALUE othtob    1='(1) Daily' 2='(2) Almost daily (3-6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (25-51 days a year)'
                  5='(5) 1 or 2 times a month (12-24 days a year)'
                  6='(6) Every other month or so (6-11 days a year)'
                  7='(7) 3-5 days this past year' 8='(8) 1 or 2 days this past year'
                  91='(91) NEVER USED SMOKELESS TOBACCO IN LIFETIME'
                  93='(93) DID NOT USE SMOKELESS TOBACCO IN THE PAST YEAR'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE addalc    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addmj     1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addsed    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addtran   1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addamp    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addcoc    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addlsd    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addher    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addcig    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addnone   1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addall    1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alctry    91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past month LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO' ;
  VALUE alcpref   1='(1) Beer' 2='(2) Wine' 3='(3) Liquor' 4='(4) It varies'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcdays   91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30a   91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE modr30dy  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcage    91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) NEVER USED ALCOHOL ONCE A MONTH OR MORE' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpat    1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' ;
  VALUE drunkyr   1='(1) Daily' 2='(2) Almost daily or 3 to 6 days a week'
                  3='(3) About 1 or 2 days a week'
                  4='(4) Several times a month (about 25-51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  9='(9) DID NOT GET DRUNK IN THE PAST 12 MONTHS'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' ;
  VALUE alcsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alctran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circle LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUOR'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alccoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alchal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER HAD A DRINK OF BEER, WINE OR LIQUO'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE butisol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE buticaps  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amytal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskabarb  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE luminal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mebaral   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amobarb   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alurate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE doriden   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noludar   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sopor     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE quaalude  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE parest    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE noctec    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chhyd     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE carbtal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pentob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE secob     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dalmane   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedoth    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   112='(112) Restoril' 120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  123='(123) Unisom <OTC>' 124='(124) Yellow jackets' 128='(128) Nervine <OTC>'
                  155='(155) Pasatorim' 156='(156) Sodium barbitol'
                  991='(991) NEVER TOOK ANY SEDATIVE' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewb   991='(991) NEVER TOOK ANY SEDATIVE' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sednewc   991='(991) NEVER TOOK ANY SEDATIVE' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sedage    91='(91) NEVER TOOK ANY SEDATIVE' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER TOOK ANY SEDATIVE'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE' ;
  VALUE sedalc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response not circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedtr     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedst     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedan     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled Logically Imputed'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedcoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedhal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY SEDATIVE'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as3read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE valium    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE libtab    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skly      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE serax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE verstran  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprspan  2='(2) Response not circled' 91='(91) NEVER TOOK ANY TRANQUILIZER'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE miltown   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE equanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE meprob    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE vistar    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE atarax    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benadryl  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE troth     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    224='(224) Triavil' 228='(228) see also 239' 239='(239) see also 228'
                  263='(263) Vivactil' 264='(264) sic' 265='(265) Black Caddy' 302='(302) Dexamyl'
                  991='(991) NEVER TOOK ANY TRANQUILIZER' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewb    991='(991) NEVER TOOK ANY TRANQUILIZER' 998='(998) BLANK (NO ANSWER)' ;
  VALUE trnewc    991='(991) NEVER TOOK ANY TRANQUILIZER' 998='(998) BLANK (NO ANSWER)' ;
  VALUE tranage   91='(91) NEVER TOOK ANY TRANQUILIZER' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER TOOK ANY TRANQUILIZER'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER' ;
  VALUE tralc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trsed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trstm     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trmj      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trcoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trhal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tropt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnone    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY TRANQUILIZER'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as4read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE dexed     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE eskat     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE benz      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE desoxyn   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE detamp    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE obla      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tenuate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tepanil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE didrex    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE plegine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE presate   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pondimin  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE voranil   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sanorex   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ritalin   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cylert    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimor    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  138='(138) sic' 311='(311) Preludin'
                  339='(339) Amphetamines (speed generically)' 346='(346) see also 332'
                  381='(381) P.O.T.C' 382='(382) Purple footballs' 648='(648) Designer Drugs'
                  991='(991) NEVER TOOK ANY STIMULANT' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  124='(124) Yellow jackets' 339='(339) Amphetamines (speed generically)'
                  381='(381) P.O.T.C' 991='(991) NEVER TOOK ANY STIMULANT'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  991='(991) NEVER TOOK ANY STIMULANT' 998='(998) BLANK (NO ANSWER)' ;
  VALUE stimage   91='(91) NEVER TOOK ANY STIMULANT' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 8='(8) Dont know/Not Sure'
                  91='(91) NEVER TOOK ANY STIMULANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT' ;
  VALUE stalc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stsed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sttran    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stanal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmj      1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stcoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sthal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stopt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stnone    2='(2) Response not circled' 91='(91) NEVER TOOK ANY STIMULANT'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' ;
  VALUE as5read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolene    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sk65a     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE propoxy   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE leritine  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE levodro   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE codeine   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dolop     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE westod    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analoth   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  423='(423) Percocet' 427='(427) Darvocet' 431='(431) Tylox'
                  437='(437) Parafon Forte' 438='(438) Anaprox, Naprosyn'
                  444='(444) Aspirin with Codeine, Empirin 3'
                  840='(840) Cough medicine (contents not specified)'
                  991='(991) NEVER TOOK ANY ANALGESIC' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewb  427='(427) Darvocet' 991='(991) NEVER TOOK ANY ANALGESIC'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analnewc  991='(991) NEVER TOOK ANY ANALGESIC' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analage   91='(91) NEVER TOOK ANY ANALGESIC' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER TOOK ANY ANALGESIC'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlalc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anltran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlinh    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlcoc    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlhal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlopt    2='(2) Response not circled' 91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER TOOK ANY ANALGESIC'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 12 MO'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     91='(91) NEVER HAD A CHANCE TO TRY MARIJUANA OR HASHISH'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjage     91='(91) NEVER USED MARIJUANA OR HASHISH' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED MARIJUANA OR HASHISH'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past week'
                  2='(2) More than 1 week ago but less than 1 month ago)'
                  3='(3) More than 1 month ago but less than 6 months ago)'
                  4='(4) More than 6 months ago but less than 1 year ago)'
                  5='(5) More than 1 year ago but less than 3 years ago'
                  6='(6) More than 3 years ago'
                  7='(7) Use in past month LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH' ;
  VALUE mjday30a  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjamt30a  1='(1) Less than 10 joints in the past 30 days'
                  2='(2) 10 to 20 joints in the past 30 days'
                  3='(3) About 1 ounce in the past 30 days'
                  4='(4) About 2 ounces in the past 30 days'
                  5='(5) 3 to 4 ounces in the past 30 days'
                  6='(6) 5 to 6 ounces in the past 30 days'
                  7='(7) Unspecified but > 6 ounces in the past 3'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjdol     0='(0) No money spent on marijuana in past 30 days'
                  9991='(9991) NEVER USED MARIJUANA OR HASHISH'
                  9993='(9993) DID NOT USE MARIJUANA OR HASHISH IN PAST 30 DAYS'
                  9994='(9994) DONT KNOW' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE mjalc30a  1='(1) Always drank alcohol with marijuana'
                  2='(2) More than half the times' 3='(3) About half the times'
                  4='(4) Less than half the times' 5='(5) One or two times'
                  6='(6) NEVER DRANK ALCOHOL W/MARIJUANA IN PAST'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAYS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjyrfreq  1='(1) Several times a day' 2='(2) Daily'
                  3='(3) Almost daily (3 to 6 days a week)'
                  4='(4) 1 or 2 days a week'
                  5='(5) Several times a month (about 25 to 51 days a year)'
                  6='(6) 1 to 2 times a month (12 to 24 days a year)'
                  7='(7) Every other month or so (6 to 11 days a year)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 or 2 days in the past 12 months'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjalc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjsed     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjtran    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjstm     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjanal    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjinh     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjcoc     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA OR HASH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjhal     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopt     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjnone    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED MARIJUANA OR HASHISH'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE as7read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 18)' ;
  VALUE inhnone   91='(91) NEVER USED AN INHALANT' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amylnit   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othinhl   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   504='(504) Shoeshine liq, glue,toluene,Super Glue,rubber cem'
                  509='(509) Corr flds, degreasers, cleaning flds, Liquid Paper'
                  511='(511) Markers, felt-tip pens, ink pens' 515='(515) Vicks'
                  516='(516) Freon' 519='(519) Helium' 526='(526) Nail polish'
                  528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med., bronchial dilators'
                  540='(540) PAM' 991='(991) NEVER USED AN INHALANT'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE gas30a    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sppan30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE glue30a   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE solvn30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE amlnt30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ether30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nox30a    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE clfl30a   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhot30a  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inh30no   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED AN INHALANT'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past week'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) more than 1 month ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past 12 months LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED AN INHALANT' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  91='(91) NEVER USED AN INHALANT'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inheff    1='(1) Enough to feel it a little' 2='(2) Enough to feel it a lot'
                  3='(3) Enough to get high'
                  4='(4) Enough until you staggered or dropped things'
                  5='(5) Enough to feel you were going to pass out'
                  6='(6) Something else (NOT SPECIFIED)'
                  91='(91) NEVER USED AN INHALANT' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhpo     1='(1) Yes' 2='(2) No' 91='(91) NEVER USED AN INHALANT'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhqnc    1='(1) All clear'
                  2='(2) R recorded question numbers (NOT SPECIFIED)'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (IRAGE > 17)' ;
  VALUE inhansy   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE > 17)' ;
  VALUE as8read   1='(1) Wants interviewer to read questions'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopp    91='(91) NEVER HAD A CHANCE TO TRY COCAINE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocage    91='(91) NEVER USED COCAINE' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED COCAINE' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past 30 days LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocam30a  1='(1) Less than 1/4 gram--about 4 big lines pst 30 days'
                  2='(2) 1/4 to 1/2 gram in past 30 days'
                  3='(3) About 1/2 to 1 gram in past 30 days'
                  4='(4) More than 1 gram (amt unspecified) in past 30 days'
                  5='(5) Less than 4 lines' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocbuck   0='(0) No money spent on cocaine in past 30 day'
                  9991='(9991) NEVER USED COCAINE'
                  9993='(9993) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  9995='(9995) BAD DATA' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE coc30alc  1='(1) Always drank alcohol with cocaine'
                  2='(2) More than half the times' 3='(3) About half the times'
                  4='(4) Less than half the times' 5='(5) One or two times'
                  6='(6) Never drank alcohol w/cocaine in past 30 days'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocyrfrq  1='(1) Daily' 2='(2) Almost daily (3 to 6 days a week)'
                  3='(3) 1 or 2 days a week'
                  4='(4) Several times a month (about 25 to 51 days a year)'
                  5='(5) 1 to 2 times a month (12 to 24 days a year)'
                  6='(6) Every other month or so (6 to 11 days a year)'
                  7='(7) 3 to 5 days in the past 12 months'
                  8='(8) 1 or 2 days in the past 12 months'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocalc    1='(1) Response Circled' 2='(2) Response not circled'
                  3='(3) Response Circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsed    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coctran   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocstm    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocanal   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocmj     1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocinh    1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cochal    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopt    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocnone   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocsnifx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocswalx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocivx    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE freebasx  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocothx   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as9read   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallqcl   1='(1) Yes' 2='(2) No/Not Sure' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   91='(91) NEVER HAD A CHANCE TO TRY HALLUCINOGENS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallage   91='(91) NEVER USED A HALLUCINOGEN' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED A HALLUCINOGEN'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  7='(7) Use in past month LOGICALLY IMPUTED'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  91='(91) NEVER USED A HALLUCINOGEN'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30 DAYS'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lsd       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halloth   1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED A HALLUCINOGEN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   267='(267) Marazine' 601='(601) see also 618' 606='(606) sic' 614='(614) MDA'
                  624='(624) Orange sunshine, sunshine, yellow sunshine'
                  644='(644) Spanish' 649='(649) Tea' 650='(650) Daytura' 651='(651) Mellow Yellow'
                  991='(991) NEVER USED A HALLUCINOGEN' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halnewb   618='(618) see also 601' 991='(991) NEVER USED A HALLUCINOGEN'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpflash  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpsense  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpfeelv  1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpactv   1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpoth    1='(1) Response circled' 2='(2) Response not circled'
                  6='(6) Never had any reaction' 91='(91) NEVER USED PCP'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnorct  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED PCP' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnewa   1='(1) High, R just felt high'
                  2='(2) Happy, energetic, just felt good, did fun things'
                  3='(3) Hallucinated, saw things' 4='(4) Numb'
                  5='(5) Disoriented, memory loss, in a trance'
                  6='(6) Lifeless, could hardly move, slow motion' 7='(7) Paranoid'
                  8='(8) Felt sick' 10='(10) Scared'
                  11='(11) Light, could float on air, free to fly' 12='(12) Weird'
                  13='(13) Withdrawn, introverted, confined to self' 15='(15) Restless'
                  16='(16) Laid back, relaxed'
                  17='(17) In deep thought, appreciation of life'
                  18='(18) Convulsions, hot & cold sweats' 19='(19) Highly sexual'
                  20='(20) Prickly sensation all over' 21='(21) Passed out'
                  22='(22) Tracers' 91='(91) NEVER USED PCP' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcpnewb   5='(5) Disoriented, memory loss, in a trance'
                  6='(6) Lifeless, could hardly move, slow motion'
                  13='(13) Withdrawn, introverted, confined to myself'
                  91='(91) NEVER USED PCP' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as10read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE heropp    91='(91) NEVER HAD A CHANCE TO TRY HEROIN'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    91='(91) NEVER USED HEROIN' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 5 times' 3='(3) 6 to 10 times'
                  4='(4) 11 to 49 times' 5='(5) 50 to 99 times' 6='(6) 100 to 199 times'
                  7='(7) 200 or more times' 91='(91) NEVER USED HEROIN' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago'
                  8='(8) Use in past 12 months LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED HEROIN' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE highbp    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE bpmed     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (HIGHBP = 2)' ;
  VALUE walkpain  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE timepain  1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE upshor    1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE asthma    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trpsych   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heart     1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE flu       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE allerg    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hospyr    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE soreyr    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE runnyyr   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coughyr   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phlegmyr  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE healthyr  1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE feltgood  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltmind  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltdep   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE felteff   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE felthope  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltslep  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE felthap   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltunf   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltenj   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltcry   1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltdisl  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE feltnogo  1='(1) Rarely or none of the time (less than a day)'
                  2='(2) Some or a little of the time (1-2 days)'
                  3='(3) Occasionally/moderate amnt of time (3-4 days)'
                  4='(4) Most or all of the time (5-7 days)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE as11read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodrugs   1='(1) Response circled' 2='(2) Response not circled' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cdcigx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdalcx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdsedx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdtranx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdstmx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdanalx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdmjx     1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdinhx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdcocx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdhallx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdherx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdothopx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE cdnonex   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effcigx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effalcx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effsedx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE efftranx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effstmx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effanalx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effmjx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effinhx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effcocx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effhallx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effherx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effothox  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE effnonex  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaycigx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayalcx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaysedx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaytrax  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaystmx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayanax  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaymjx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayinhx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaycocx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayhalx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayherx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udayothx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE udaynonx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depcigx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depalcx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depsedx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE deptranx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depstmx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depanalx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depmjx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depinhx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depcocx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE dephallx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depherx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depothox  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE depnonex  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wscigx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsalcx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wssedx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wstranx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsstmx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsanalx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsmjx     1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsinhx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wscocx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wshallx   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsherx    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsothopx  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE wsnonex   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGS = 1)' ;
  VALUE noboozyr  1='(1) Response circled' 2='(2) Response not circled' 95='(95) BAD DATA' ;
  VALUE alcaggr   1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcargum  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcabsnt  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alchigh   1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcjob    1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcmatcd  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcrelcd  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcfrdcd  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alctoss   1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcholic  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcdrunk  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcintox  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcrem    1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcquick  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcmorn   1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcshook  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcalone  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE alcbrkpm  1='(1) Yes, had experience in past 12 months'
                  2='(2) No, had not had experience in past 12 months'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NOBOOZYR = 1)' ;
  VALUE as13none  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drdeprss  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE depdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  207='(207) Ativan' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  312='(312) Ionamin' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE depdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  157='(157) Barbiturates' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  701='(701) OTHER Opiates, NOT SPECIFIED'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE depdrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE depdrg4a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE depdrg5a  803='(803) sic' 807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE depdrg6a  805='(805) Cocaine, coke' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDEPRSS = 2 OR 99)' ;
  VALUE drargum   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE argdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 312='(312) Ionamin'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE argdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  157='(157) Barbiturates' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE argdrg3a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE argdrg4a  601='(601) LSD (acid, white lightning) [see als'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE argdrg5a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE argdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRARGUM = 2 OR 99)' ;
  VALUE drtrble   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE trbdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  207='(207) Ativan' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 605='(605) PCP (angel dust, phencyclidine)'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE trbdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE trbdrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE trbdrg4a  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE trbdrg5a  415='(415) Codeine'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE trbdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLE = 2 OR 99)' ;
  VALUE drdrive   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE drvdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drvdrg2a  157='(157) Barbiturates'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drvdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drvdrg4a  362='(362) Benadryl' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drvdrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drvdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRDRIVE = 2 OR 99)' ;
  VALUE drntrmb   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE nrmdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  207='(207) Ativan' 311='(311) Preludin'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning) [see als'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE nrmdrg2a  116='(116) Methaqualone, Quaalude, Sopor' 157='(157) Barbiturates'
                  201='(201) Valium' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE nrmdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE nrmdrg4a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE nrmdrg5a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE nrmdrg6a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNTRMB = 2 OR 99)' ;
  VALUE dralone   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE alndrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  207='(207) Ativan' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 603='(603) Mescaline'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE alndrg2a  157='(157) Barbiturates' 201='(201) Valium'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED' 362='(362) Benadryl'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE alndrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE alndrg4a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE alndrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE alndrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRALONE = 2 OR 99)' ;
  VALUE dranx     1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE anxdrg1a  109='(109) Seconal' 120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  201='(201) Valium' 207='(207) Ativan'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 301='(301) Dexedrine'
                  312='(312) Ionamin' 324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  362='(362) Benadryl' 510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 603='(603) Mescaline'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE anxdrg2a  157='(157) Barbiturates' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE anxdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE anxdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE anxdrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE anxdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRANX = 2 OR 99)' ;
  VALUE drhealth  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE hltdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED' 407='(407) Demerol'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE hltdrg2a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 702='(702) Heroin' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE hltdrg3a  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE hltdrg4a  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE hltdrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE hltdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRHEALTH = 2 OR 99)' ;
  VALUE drnthink  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE ntkdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  239='(239) see also 228'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  503='(503) Other aerosol sprays'
                  601='(601) LSD (acid, white lightning) [see als' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE ntkdrg2a  157='(157) Barbiturates' 201='(201) Valium'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  601='(601) LSD (acid, white lightning) [see als'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE ntkdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms)' 803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE ntkdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE ntkdrg5a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE ntkdrg6a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTHINK = 2 OR 99)' ;
  VALUE drmnyprb  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE mnydrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE mnydrg2a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE mnydrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning) [see als'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE mnydrg4a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE mnydrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE mnydrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRMNYPRB = 2 OR 99)' ;
  VALUE drupset   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE upsdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 312='(312) Ionamin'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  601='(601) LSD (acid, white lightning) [see als' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)'
                  701='(701) OTHER Opiates, NOT SPECIFIED' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE upsdrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  157='(157) Barbiturates' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE upsdrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE upsdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE upsdrg5a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE upsdrg6a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRUPSET = 2 OR 99)' ;
  VALUE drlswork  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE lswdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  415='(415) Codeine' 803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE lswdrg2a  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE lswdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  805='(805) Cocaine, coke' 994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE lswdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE lswdrg5a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE lswdrg6a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRLSWORK = 2 0R 99)' ;
  VALUE drsuspic  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE sspdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 362='(362) Benadryl'
                  601='(601) LSD (acid, white lightning) [see als' 603='(603) Mescaline'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE sspdrg2a  157='(157) Barbiturates'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE sspdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning) [see als'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE sspdrg4a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE sspdrg5a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE sspdrg6a  994='(994) DONT KNOW' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRSUSPIC = 2 OR 99)' ;
  VALUE drtrblaw  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE lawdrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE lawdrg2a  601='(601) LSD (acid, white lightning) [see als' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE lawdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE lawdrg4a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE lawdrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE lawdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRTRBLAW = 2 OR 99)' ;
  VALUE drnoteat  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE netdrg1a  201='(201) Valium' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  301='(301) Dexedrine'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)' 407='(407) Demerol'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  604='(604) Psilocybin (mushrooms)'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE netdrg2a  201='(201) Valium' 312='(312) Ionamin'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  601='(601) LSD (acid, white lightning) [see als'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE netdrg3a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE netdrg4a  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE netdrg5a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE netdrg6a  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRNOTEAT = 2 OR 99)' ;
  VALUE drcope    1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE cpedrg1a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED' 201='(201) Valium'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  605='(605) PCP (angel dust, phencyclidine)' 606='(606) sic'
                  702='(702) Heroin' 705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE cpedrg2a  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  157='(157) Barbiturates'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  601='(601) LSD (acid, white lightning) [see als'
                  705='(705) Speedball (Heroin + Cocaine)' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE cpedrg3a  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  339='(339) Amphetamines (speed generically)'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE cpedrg4a  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 805='(805) Cocaine, coke'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE cpedrg5a  803='(803) sic' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE cpedrg6a  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DRCOPE = 2 OR 99)' ;
  VALUE dremgmed  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (AS13NONE = 1)' ;
  VALUE emdrg1a   221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED' 407='(407) Demerol'
                  702='(702) Heroin' 803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE emdrg2a   803='(803) sic' 805='(805) Cocaine, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE emdrg3a   339='(339) Amphetamines (speed generically)' 805='(805) Cocaine, coke'
                  998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE emdrg4a   998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE emdrg5a   998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE emdrg6a   998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (DREMGMED = 2 OR 99)' ;
  VALUE as14read  1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hlpqtcig  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hlpalcho  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hlpdruse  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trter     1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trthosp   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtpdoc   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtreh    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtmhf    1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtshelp  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtother  1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtnone   1='(1) Response circled' 2='(2) Response not circled'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trtnewa   1='(1) Church, religious figure' 2='(2) Friend or relative'
                  3='(3) Psychiatrist/Psychologist' 4='(4) Sociologist'
                  5='(5) School counselor' 6='(6) Crisis center' 7='(7) Hypnotist'
                  8='(8) Training room' 9='(9) Transcendental meditation'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TRTOTHER = 2 OR 98)' ;
  VALUE trtnewb   98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TRTOTHER = 2 OR 98)' ;
  VALUE trtcall   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trtcallo  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trtdrgyr  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trtprbyr  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrypcp  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkpcpreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrycoc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rk2drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sex       1='(1) Male' 2='(2) Female' ;
  VALUE birmon    1='(1) January' 2='(2) February' 3='(3) March' 4='(4) April' 5='(5) May'
                  6='(6) June' 7='(7) July' 8='(8) August' 9='(9) September' 10='(10) October'
                  11='(11) November' 12='(12) December' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Has never married' 5='(5) Living as a couple' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (IRAGE < 15)' ;
  VALUE nomarr    1='(1) One' 2='(2) Two' 3='(3) Three' 4='(4) Four' 5='(5) Five' 6='(6) Six or more'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MARITAL = 4 OR 99)' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work'
                  10='(10) Something else (NOT SPECIFIED)' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE payyr     91='(91) NEVER WORKED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (WORKSTAT<4)' ;
  VALUE paymo     1='(1) January' 2='(2) February' 3='(3) March' 4='(4) April' 5='(5) May'
                  6='(6) June' 7='(7) July' 8='(8) August' 9='(9) September' 10='(10) October'
                  11='(11) November' 12='(12) December' 91='(91) NEVER WORKED FOR PAY'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (WORKSTAT < 4)' ;
  VALUE roccup1f  1='(1) Managerial/Professional Specialties'
                  2='(2) Technical, Sales and Administrative Support'
                  3='(3) Farming, Forestry and Fishing'
                  4='(4) Precision Production and Skilled Labor'
                  5='(5) Operators, Fabricators and Laborers'
                  6='(6) Unskilled Laborers, Handlers, Helpers' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (PAYYR = 91)' ;
  VALUE businesf  1='(1) Agriculture, Forestry, Fishery' 2='(2) Mining'
                  3='(3) Construction' 4='(4) Manufacturing'
                  5='(5) Transportation, Communication, Public Util'
                  6='(6) Whole Trade' 7='(7) Retail Trade'
                  8='(8) Finance, Insurance and Real Estate'
                  9='(9) Business and Repair Services' 10='(10) Personal Services'
                  11='(11) Entertainment and Recreational Services'
                  12='(12) Professional and Related Services'
                  13='(13) Public Administration' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (PAYYR = 91)' ;
  VALUE no5job    0='(0) No jobs in past 5 years' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PAYYR = 91)' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (SPECIFY)' 3='(3) No one'
                  4='(4) Co-wage earner'
                  5='(5) Spouse (husband/wife), live-in partner'
                  6='(6) Parent (father, mother, step-parent, etc)'
                  7='(7) Grandparent or other relative' 8='(8) Friend'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (RESP IS ONLY ADULT 18 OR OLDER)' ;
  VALUE fullpart  1='(1) Full-time' 2='(2) Part-time'
                  3='(3) Chief source of income does not work' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (CWE = 1, 3, 4, OR 99)' ;
  VALUE cweocc1f  1='(1) Management/Professional Specialties'
                  2='(2) Technical, Sales and administrative support'
                  3='(3) Farming, Forestry and Fishing'
                  4='(4) Precision Production and Skilled Labor'
                  5='(5) Operators, Fabricators and Laborers'
                  6='(6) Unskilled Laborers, Handlers, Helpers' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (CWE= 1,3,4 OR 99 OR FULLPART=3)' ;
  VALUE cwebus1f  1='(1) Agriculture, Forestry, Fishery' 2='(2) Mining'
                  3='(3) Construction' 4='(4) Manufacturing'
                  5='(5) Transportation, Communication and Public Util'
                  6='(6) Whole Trade' 7='(7) Retail Trade'
                  8='(8) Finance, Insurance and Real Estate'
                  9='(9) Business and Repair Services' 10='(10) Personal Services'
                  11='(11) Entertainment and Recreational Services'
                  12='(12) Professional and Related Services'
                  13='(13) Public Administration' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (CWE= 1,3,4 OR 99 OR FULLPART=3)' ;
  VALUE educ      0='(0) No schooling' 1='(1) First Grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh Grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year college'
                  14='(14) 2 years college' 15='(15) 3 years college'
                  16='(16) 4 years college' 17='(17) Graduate/professional school'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE student   1='(1) A full-time student' 2='(2) A part-time student'
                  3='(3) Dropped out of school' 4='(4) Completed schooling'
                  5='(5) Starting school in the fall' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (EDUC = 0)' ;
  VALUE schdays   0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (STUDENT = 3, 4, 5, OR 99)' ;
  VALUE skipped   0='(0) Never skipped school in last month' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (STUDENT = 3, 4, 5, OR 99)' ;
  VALUE workdays  0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (WORKSTAT = 4 - 10)' ;
  VALUE workblah  0='(0) None' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (WORKSTAT = 4 - 10)' ;
  VALUE miles     99991='(99991) HAS NEVER DRIVEN A MOTOR VEHICLE' 99994='(99994) DONT KNOW'
                  99997='(99997) REFUSED' 99998='(99998) BLANK (NO ANSWER)'
                  99999='(99999) LEGITIMATE SKIP (IRAGE < 15)' ;
  VALUE accid     1='(1) Yes' 2='(2) No' 3='(3) Did not drive in past 12 months'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 15 OR MILES = 99991)' ;
  VALUE nochild   0='(0) No children' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (IRAGE < 15)' ;
  VALUE totpeop   1='(1) R lives alone' 97='(97) REFUSED' ;
  VALUE mother    0='(0) Not present and/or inapplicable'
                  1='(1) Present in household' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE father    0='(0) Not present and/or inapplicable' 1='(1) Present'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE spouse    0='(0) Not present and/or inapplicable' 1='(1) Present'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inlaw     0='(0) Neither present and/or inapplicable' 1='(1) One present'
                  2='(2) Two present' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ownchild  0='(0) None present and/or inapplicable' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stepchld  0='(0) None present and/or inapplicable' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE brosis    0='(0) None present and/or inapplicable'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othrel    0='(0) None present and/or inapplicable'
                  93='(93) RELATION INDICATED, NO COUNT RECORDED' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE friends   0='(0) None present and/or inapplicable' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE othernon  0='(0) None present and/or inapplicable' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE service   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 17)' ;
  VALUE milstat   1='(1) On extended active duty in the armed forces'
                  2='(2) In a reserves component'
                  3='(3) Separated/retired from reserves or active duty'
                  30='(30) During what years did you serve in' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 17 OR SERVICE = 2)' ;
  VALUE milyr1a   94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE milyr2a   94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE milyr3a   1='(1) Mention of second service' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE milyr4a   1='(1) Mention of second service' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE milyr5a   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE milyr6a   97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 1, 2, OR 99)' ;
  VALUE yrents    97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (MILSTAT = 3 OR 99)' ;
  VALUE vietnam   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 17 OR SERVICE = 2)' ;
  VALUE dorm      0='(0) None' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE milbase   0='(0) None' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hosp      0='(0) None' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE telno     0='(0) None - no phone' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE moves     0='(0) None' 94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE income    1='(1) No personal earnings' 2='(2) Yearly - under $5,000'
                  3='(3) Yearly - $5,000 to $6,999' 4='(4) Yearly - $7,000 to $8,999'
                  5='(5) Yearly - $9,000 to $11,999'
                  6='(6) Yearly - $12,000 to $14,999'
                  7='(7) Yearly - $15,000 to $19,999'
                  8='(8) Yearly - $20,000 to $24,999'
                  9='(9) Yearly - $25,000 to $29,999'
                  10='(10) Yearly - $30,000 to $39,999'
                  11='(11) Yearly - $40,000 to $50,000'
                  12='(12) Yearly - More than $50,000' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (IRAGE < 15)' ;
  VALUE eiidate   1='(1) Interview date established from questionnaire'
                  3='(3) Interview date Statistically Imputed' ;
  VALUE intmonth  1='(1) January' 6='(6) June' 7='(7) July' 8='(8) August' 9='(9) September'
                  10='(10) October' 11='(11) November' 12='(12) December' ;
  VALUE parq      1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE undint    1='(1) No difficulty-no language or reading problem'
                  2='(2) Just a little difficulty-almost no lang/readg prob'
                  3='(3) Fair amount of difficulty-some lang/reading prob'
                  4='(4) A lot of difficulty-considerable lang/rereading prob'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able to overhear'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in room or listening 1/3 of the time'
                  7='(7) Serious interruptions more than half the time'
                  9='(9) Constant presence of other person(s)' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE spres     2='(2) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE parpres   3='(3) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY = 1)' ;
  VALUE oarpres   4='(4) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY = 1)' ;
  VALUE oapres    5='(5) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY = 1)' ;
  VALUE cpres     6='(6) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY=1)' ;
  VALUE opres     7='(7) Response circled' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (PRIVACY = 1)' ;
  VALUE popden    1='(1) PSU in a SMSA with 1 million or more per'
                  2='(2) PSU in a SMSA with fewer than 1 million'
                  3='(3) PSU not in a SMSA' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE eibdate   1='(1) Birthdate established form questionnaire'
                  2='(2) Portions of birthdate logically imputed'
                  4='(4) Birthdate exists and IRAGE differs by 1+' ;
  VALUE iiage     1='(1) Age from birthdate'
                  2='(2) Final Age as Reported on Original File' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire' ;
  VALUE irrace    1='(1) American indian/Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White'
                  9='(9) Hispanic' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race Logically Imputed from Hispanicity'
                  4='(4) Race Status imputed using race - Other' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Non-Hispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  3='(3) Hispanicity statistically imputed'
                  9='(9) Questionnaire Response Indicates Resp not Hispanic' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP (IRHOIND = 2)' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questionnaire'
                  3='(3) Statistically imputed data'
                  9='(9) Questionnaire Response Indicates Resp not Hispanic' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American/Caribbean' 6='(6) South American'
                  99='(99) LEGITIMATE SKIP (IRHOIND = 2)' ;
  VALUE iihogrpf  1='(1) Puerto Rican' 3='(3) Statistically imputed data'
                  9='(9) Questionnaire Response Indicates Resp not Hispanic' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP (IRAGE < 15 )' ;
  VALUE iimarit   1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP (IRAGE < 15)' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) One year of college'
                  14='(14) Two years of college' 15='(15) Three years of college'
                  16='(16) Four years of college'
                  17='(17) Graduate/professional school' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a week'
                  2='(2) Working part-time, less than 35 hours a week'
                  3='(3) Have job but out: illness/leave/furlough/strike'
                  4='(4) Unemployed or laid off and looking for work'
                  5='(5) Unemployed and not looking for work'
                  6='(6) Full-time homemaker only' 7='(7) In school only' 8='(8) Retired'
                  9='(9) Disabled, not able to work' 12='(12) Other' ;
  VALUE iiworkst  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past week (7 days)'
                  2='(2) More than 1 week ago but less than 1 month ago'
                  3='(3) 1 or more months ago but less than 6 months ago'
                  4='(4) 6 or more months ago but less than 1 year ago'
                  5='(5) 1 or more years ago but less than 3 years ago'
                  6='(6) 3 or more years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 6 months ago'
                  3='(3) 6 or more months ago but less than 1 year ago'
                  4='(4) 1 or more years ago but less than 3 years ago'
                  5='(5) 3 or more years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times a month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used several times per day in past year'
                  2='(2) Used daily in past year'
                  3='(3) Used almost daily in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used several times per month in past year'
                  6='(6) Used 1-2 times per month in past year'
                  7='(7) Used every other month in past year'
                  8='(8) Used 3-5 times in past year'
                  9='(9) Used 1-2 times in past year'
                  10='(10) Never used or did not use in the past year' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used almost daily in past year'
                  3='(3) Used 1-2 days per week in past year'
                  4='(4) Used several times per month in past year'
                  5='(5) Used 1-2 times per month in past year'
                  6='(6) Used every other month in past year'
                  7='(7) Used 3-5 times in past year'
                  8='(8) Used 1-2 times in past year'
                  9='(9) Never used or did not use in the past year' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years (IRAGE = 12-17)'
                  2='(2) 18-25 years (IRAGE = 18-25)'
                  3='(3) 26-34 years (IRAGE = 26-34)' 4='(4) 35+ years (IRAGE > 34)' ;
  VALUE catag2ff  1='(1) 12-17 years (CATAGE = 1)' 2='(2) 18-25 years (CATAGE = 2)'
                  3='(3) 26+ years (CATAGE = 3-4)' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and IRAGE => 18)'
                  2='(2) High school graduate (IREDUC = 12 and IRAGE => 18)'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE => 18)'
                  4='(4) College graduate (IREDUC = 16-17 and IRAGE => 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full=time (IRWORKST =1,3 and IRAGE => 18)'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,10 and IRAGE => 18)'
                  4='(4) Other (IRWORKST = 6-9, 12 and IRAGE >= 18)'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-5)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC = 4-5, 9)'
                  1='(1) Used within the past year (IRCIGRC = 1-3)' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC = 2-5, 9)'
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-5)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC = 4-5, 9)'
                  1='(1) Used within the past year (IRALCRC = 1-3)' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC = 2-5,9)'
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-5)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC = 4-5, 9)'
                  1='(1) Used within the past year (IRSEDRC = 1-3)' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC = 2-5, 9)'
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-5)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC = 4-5, 9)'
                  1='(1) Used within the past year (IRTRNRC = 1-3)' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC ='
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-5)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC = 4-5, 9)'
                  1='(1) Used within the past year (IRSTMRC = 1-3)' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC = 2-5, 9)'
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-5)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC = 4-5, 9)'
                  1='(1) Used within the past year (IRANLRC = 1-3)' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC = 2-5, 9)'
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1 - 6)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 5-6, 9)'
                  1='(1) Used within the past year (IRMJRC = 1-4)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC = 3-6, 9)'
                  1='(1) Used within the past month (IRMJRC = 1-2)' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-6)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC = 5-6, 9)'
                  1='(1) Used within the past year (IRINHRC = 1-4)' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC = 3-6, 9)'
                  1='(1) Used within the past month (IRINHRC = 1-2)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-5)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC = 4-5, 9)'
                  1='(1) Used within the past year (IRCOCRC = 1-3)' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC = 2-5, 9)'
                  1='(1) Used within the past month (IRCOCRC = 1)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-5)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC = 4-5, 9)'
                  1='(1) Used within the past year (IRHALRC = 1-3)' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC = 2-5, 9)'
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-5)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC = 4-5, 9)'
                  1='(1) Used within the past year (IRPCPRC = 1-3)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC = 2-5, 9)'
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-5)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC = 4-5, 9)'
                  1='(1) Used within the past year (IRHERRC = 1-3)' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRL = 2-5, 9)'
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE VARS > 3)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE < 4)' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VARS > 1)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VARS = 0)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE = 1)' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VARS = 0)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ever used' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost daily pst yr (IRALCFQ = 3, 9)'
                  1='(1) Used daily/almost daily in past year (IRALCFQ = 1, 2)' ;
  VALUE alcwkf    0='(0) Did not use weekly or more past yr (IRALCFQ = 4-9)'
                  1='(1) Used weekly or more in past year (IRALCFQ = 1-3)' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRALCFQ = 6-9)'
                  1='(1) Used monthly or more often past yr (IRALCFQ = 1-5)' ;
  VALUE alcoccf   0='(0) Used monthly/more or none in pst yr (IRALCFQ = 1-5, 9)'
                  1='(1) Used past year but less than monthly (IRALCFQ = 6-8)' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRAlCFQ = 9)'
                  1='(1) Any use within the past year (IRALCFQ = 1-8)' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr (IRMJFQ = 4-10)'
                  1='(1) Used daily/almost daily in past year (IRMJFQ = 1-3)' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJFQ = 5-10)'
                  1='(1) Used weekly or more in past year (IRMJFQ = 1-4)' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJFQ = 7-10)'
                  1='(1) Used monthly or more in past year (IRMJFQ = 1-6)' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr (IRMJFQ = 1-6, 10)'
                  1='(1) Used past year but less than monthly (IRMJFQ = 7-9)' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past yr (IRMJFQ = 10)'
                  1='(1) Any use within the past year (IRMJFQ = 1-9)' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost daily pst yr (IRCOCFQ = 3-9)'
                  1='(1) Used daily/almost daily in past year (IRCOCFQ = 1-2)' ;
  VALUE cocwkf    0='(0) Did not use weekly or more past yr (IRCOCFQ = 4-9)'
                  1='(1) Used weekly or more often past yr (IRCOCFQ = 1-3)' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCOCFQ = 6-9)'
                  1='(1) Used monthly or more often past yr (IRCOCFQ = 1-5)' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr (IRCOCFQ = 6-9)'
                  1='(1) Used past year but less than monthly (IRCOCFQ = 6-8)' ;
  VALUE cocyrf    0='(0) Never used or did not use in past yr (IRCOCFQ = 9)'
                  1='(1) Any use within the past year (IRCOCFQ = 1-8)' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=1559;
INPUT
        CASEID 1-4              RESPID 5-8              ENCPSU 9-11
        CIGTRY 12-13            CIG5PK 14-15            CIGREC 16-17
        AVCIG 18-19             CIGINT 20-21            CIGTIME 22-23
        CIGAGE 24-25            CIGYRS 26-27            PACKS 28-29
        OTHTOB 30-31            ADDALC 32-33            ADDMJ 34-35
        ADDSED 36-37            ADDTRAN 38-39           ADDAMP 40-41
        ADDCOC 42-43            ADDLSD 44-45            ADDHER 46-47
        ADDCIG 48-49            ADDNONE 50-51           ADDALL 52-53
        ALCTRY 54-55            ALCREC 56-57            ALCPREF 58-59
        ALCDAYS 60-61           NODR30A 62-63           MODR30A 64-65
        MODR30DY 66-67          DR5DAY 68-69            ALCAGE 70-71
        ALCPAT 72-73            DRUNKYR 74-75           ALCSED 76-77
        ALCTRAN 78-79           ALCSTM 80-81            ALCANAL 82-83
        ALCMJ 84-85             ALCINH 86-87            ALCCOC 88-89
        ALCHAL 90-91            ALCOPT 92-93            ALCNONE 94-95
        NOSEDAT 96              BUTISOL 97-98           BUTICAPS 99-100
        AMYTAL 101-102          ESKABARB 103-104        LUMINAL 105-106
        MEBARAL 107-108         AMOBARB 109-110         PHENOBAR 111-112
        ALURATE 113-114         PLACIDYL 115-116        DORIDEN 117-118
        NOLUDAR 119-120         SOPOR 121-122           QUAALUDE 123-124
        PAREST 125-126          NOCTEC 127-128          METHAQ 129-130
        CHHYD 131-132           NEMBUTAL 133-134        CARBTAL 135-136
        SECONAL 137-138         TUINAL 139-140          PENTOB 141-142
        SECOB 143-144           DALMANE 145-146         SEDDKNAM 147-148
        SEDOTH 149-150          SEDNEWA 151-153         SEDNEWB 154-156
        SEDNEWC 157-159         SEDAGE 160-161          SEDTOT 162-163
        SEDREC 164-165          SEDALC 166-167          SEDTR 168-169
        SEDST 170-171           SEDAN 172-173           SEDMJ 174-175
        SEDINH 176-177          SEDCOC 178-179          SEDHAL 180-181
        SEDOPT 182-183          SEDNONE 184-185         AS3READ 186-187
        NOTRANQ 188             VALIUM 189-190          LIBRIUM 191-192
        LIBTAB 193-194          SKLY 195-196            SERAX 197-198
        TRANXENE 199-200        ATIVAN 201-202          VERSTRAN 203-204
        MEPRSPAN 205-206        MILTOWN 207-208         EQUANIL 209-210
        MEPROB 211-212          VISTAR 213-214          ATARAX 215-216
        BENADRYL 217-218        XANAX 219-220           TRDKNAM 221-222
        TROTH 223-224           TRNEWA 225-227          TRNEWB 228-230
        TRNEWC 231-233          TRANAGE 234-235         TRANTOT 236-237
        TRANREC 238-239         TRALC 240-241           TRSED 242-243
        TRSTM 244-245           TRANAL 246-247          TRMJ 248-249
        TRINH 250-251           TRCOC 252-253           TRHAL 254-255
        TROPT 256-257           TRNONE 258-259          AS4READ 260-261
        NOSTIMS 262             DEXED 263-264           DEXAMYL 265-266
        ESKAT 267-268           BENZ 269-270            BIPHET 271-272
        DESOXYN 273-274         DETAMP 275-276          METHI 277-278
        OBLA 279-280            TENUATE 281-282         TEPANIL 283-284
        DIDREX 285-286          PLEGINE 287-288         PRELUDIN 289-290
        PRESATE 291-292         IONAMIN 293-294         PONDIMIN 295-296
        VORANIL 297-298         SANOREX 299-300         RITALIN 301-302
        CYLERT 303-304          STMDKNAM 305-306        STIMOR 307-308
        STIMNEWA 309-311        STIMNEWB 312-314        STIMNEWC 315-317
        STIMAGE 318-319         STIMTOT 320-321         STIMREC 322-323
        STALC 324-325           STSED 326-327           STTRAN 328-329
        STANAL 330-331          STMJ 332-333            STINH 334-335
        STCOC 336-337           STHAL 338-339           STOPT 340-341
        STNONE 342-343          AS5READ 344-345         ANALNONE 346-347
        DARVON 348-349          DOLENE 350-351          SK65A 352-353
        PROPOXY 354-355         LERITINE 356-357        LEVODRO 358-359
        PERCODAN 360-361        DEMEROL 362-363         DILAUD 364-365
        TYLCOD 366-367          CODEINE 368-369         DOLOP 370-371
        WESTOD 372-373          METHDON 374-375         TALWIN 376-377
        ANLDKNAM 378-379        ANALOTH 380-381         ANALNEWA 382-384
        ANALNEWB 385-387        ANALNEWC 388-390        ANALAGE 391-392
        ANALTOT 393-394         ANALREC 395-396         ANLALC 397-398
        ANLSED 399-400          ANLTRAN 401-402         ANLSTM 403-404
        ANLMJ 405-406           ANLINH 407-408          ANLCOC 409-410
        ANLHAL 411-412          ANLOPT 413-414          ANLNONE 415-416
        MJOPP 417-418           MJAGE 419-420           MJTOT 421-422
        MJREC 423-424           MJDAY30A 425-426        MJAV30A 427-428
        MJAMT30A 429-430        MJDOL 431-434           MJALC30A 435-436
        MJYRFREQ 437-438        MJALC 439-440           MJSED 441-442
        MJTRAN 443-444          MJSTM 445-446           MJANAL 447-448
        MJINH 449-450           MJCOC 451-452           MJHAL 453-454
        MJOPT 455-456           MJNONE 457-458          AS7READ 459-460
        INHNONE 461-462         GAS 463-464             SPPAINT 465-466
        AEROS 467-468           GLUE 469-470            SOLVENT 471-472
        AMYLNIT 473-474         ETHER 475-476           NITOXID 477-478
        CLEFLU 479-480          OTHINHL 481-482         INHNEWA 483-485
        GAS30A 486-487          SPPAN30A 488-489        AEROS30A 490-491
        GLUE30A 492-493         SOLVN30A 494-495        AMLNT30A 496-497
        ETHER30A 498-499        NOX30A 500-501          CLFL30A 502-503
        INHOT30A 504-505        INH30NO 506-507         INHTOT 508-509
        INHREC 510-511          INHDY30A 512-513        INHEFF 514-515
        INHPO 516-517           INHQNC 518-519          INHANSY 520-521
        AS8READ 522-523         COCOPP 524-525          COCAGE 526-527
        COCTOT 528-529          COCREC 530-531          COCUS30A 532-533
        COCAM30A 534-535        COCBUCK 536-539         COC30ALC 540-541
        COCYRFRQ 542-543        COCALC 544-545          COCSED 546-547
        COCTRAN 548-549         COCSTM 550-551          COCANAL 552-553
        COCMJ 554-555           COCINH 556-557          COCHAL 558-559
        COCOPT 560-561          COCNONE 562-563         COCSNIFX 564-565
        COCSWALX 566-567        COCIVX 568-569          FREEBASX 570-571
        COCOTHX 572-573         AS9READ 574-575         HALLQCL 576-577
        HALLOPP 578-579         HALLAGE 580-581         HALLTOT 582-583
        HALLREC 584-585         HAL30USE 586-587        LSD 588-589
        PEYOTE 590-591          MESC 592-593            PSILCY 594-595
        PCP 596-597             HALLOTH 598-599         HALNEWA 600-602
        HALNEWB 603-605         PCPREC 606-607          PCPFLASH 608-609
        PCPSENSE 610-611        PCPFEELV 612-613        PCPACTV 614-615
        PCPOTH 616-617          PCPNORCT 618-619        PCPNEWA 620-621
        PCPNEWB 622-623         AS10READ 624-625        HEROPP 626-627
        HERAGE 628-629          HERTOT 630-631          HERREC 632-633
        HER30USE 634-635        HERNEEDL 636-637        HIGHBP 638-639
        BPMED 640-641           WALKPAIN 642-643        TIMEPAIN 644-645
        UPSHOR 646-647          ASTHMA 648-649          TRPSYCH 650-651
        HEART 652-653           FLU 654-655             ALLERG 656-657
        HOSPYR 658-659          SOREYR 660-661          RUNNYYR 662-663
        COUGHYR 664-665         PHLEGMYR 666-667        HEALTHYR 668-669
        FELTGOOD 670-671        FELTMIND 672-673        FELTDEP 674-675
        FELTEFF 676-677         FELTHOPE 678-679        FELTSLEP 680-681
        FELTHAP 682-683         FELTUNF 684-685         FELTENJ 686-687
        FELTCRY 688-689         FELTDISL 690-691        FELTNOGO 692-693
        AS11READ 694-695        NODRUGS 696-697         CDCIGX 698-699
        CDALCX 700-701          CDSEDX 702-703          CDTRANX 704-705
        CDSTMX 706-707          CDANALX 708-709         CDMJX 710-711
        CDINHX 712-713          CDCOCX 714-715          CDHALLX 716-717
        CDHERX 718-719          CDOTHOPX 720-721        CDNONEX 722-723
        EFFCIGX 724-725         EFFALCX 726-727         EFFSEDX 728-729
        EFFTRANX 730-731        EFFSTMX 732-733         EFFANALX 734-735
        EFFMJX 736-737          EFFINHX 738-739         EFFCOCX 740-741
        EFFHALLX 742-743        EFFHERX 744-745         EFFOTHOX 746-747
        EFFNONEX 748-749        UDAYCIGX 750-751        UDAYALCX 752-753
        UDAYSEDX 754-755        UDAYTRAX 756-757        UDAYSTMX 758-759
        UDAYANAX 760-761        UDAYMJX 762-763         UDAYINHX 764-765
        UDAYCOCX 766-767        UDAYHALX 768-769        UDAYHERX 770-771
        UDAYOTHX 772-773        UDAYNONX 774-775        DEPCIGX 776-777
        DEPALCX 778-779         DEPSEDX 780-781         DEPTRANX 782-783
        DEPSTMX 784-785         DEPANALX 786-787        DEPMJX 788-789
        DEPINHX 790-791         DEPCOCX 792-793         DEPHALLX 794-795
        DEPHERX 796-797         DEPOTHOX 798-799        DEPNONEX 800-801
        WSCIGX 802-803          WSALCX 804-805          WSSEDX 806-807
        WSTRANX 808-809         WSSTMX 810-811          WSANALX 812-813
        WSMJX 814-815           WSINHX 816-817          WSCOCX 818-819
        WSHALLX 820-821         WSHERX 822-823          WSOTHOPX 824-825
        WSNONEX 826-827         NOBOOZYR 828-829        ALCAGGR 830-831
        ALCARGUM 832-833        ALCABSNT 834-835        ALCHIGH 836-837
        ALCJOB 838-839          ALCMATCD 840-841        ALCRELCD 842-843
        ALCFRDCD 844-845        ALCTOSS 846-847         ALCHOLIC 848-849
        ALCDRUNK 850-851        ALCINTOX 852-853        ALCREM 854-855
        ALCQUICK 856-857        ALCMORN 858-859         ALCSHOOK 860-861
        ALCALONE 862-863        ALCBRKPM 864-865        AS13NONE 866-867
        DRDEPRSS 868-869        DEPDRG1A 870-872        DEPDRG2A 873-875
        DEPDRG3A 876-878        DEPDRG4A 879-881        DEPDRG5A 882-884
        DEPDRG6A 885-887        DRARGUM 888-889         ARGDRG1A 890-892
        ARGDRG2A 893-895        ARGDRG3A 896-898        ARGDRG4A 899-901
        ARGDRG5A 902-904        ARGDRG6A 905-907        DRTRBLE 908-909
        TRBDRG1A 910-912        TRBDRG2A 913-915        TRBDRG3A 916-918
        TRBDRG4A 919-921        TRBDRG5A 922-924        TRBDRG6A 925-927
        DRDRIVE 928-929         DRVDRG1A 930-932        DRVDRG2A 933-935
        DRVDRG3A 936-938        DRVDRG4A 939-941        DRVDRG5A 942-944
        DRVDRG6A 945-947        DRNTRMB 948-949         NRMDRG1A 950-952
        NRMDRG2A 953-955        NRMDRG3A 956-958        NRMDRG4A 959-961
        NRMDRG5A 962-964        NRMDRG6A 965-967        DRALONE 968-969
        ALNDRG1A 970-972        ALNDRG2A 973-975        ALNDRG3A 976-978
        ALNDRG4A 979-981        ALNDRG5A 982-984        ALNDRG6A 985-987
        DRANX 988-989           ANXDRG1A 990-992        ANXDRG2A 993-995
        ANXDRG3A 996-998        ANXDRG4A 999-1001       ANXDRG5A 1002-1004
        ANXDRG6A 1005-1007      DRHEALTH 1008-1009      HLTDRG1A 1010-1012
        HLTDRG2A 1013-1015      HLTDRG3A 1016-1018      HLTDRG4A 1019-1021
        HLTDRG5A 1022-1024      HLTDRG6A 1025-1027      DRNTHINK 1028-1029
        NTKDRG1A 1030-1032      NTKDRG2A 1033-1035      NTKDRG3A 1036-1038
        NTKDRG4A 1039-1041      NTKDRG5A 1042-1044      NTKDRG6A 1045-1047
        DRMNYPRB 1048-1049      MNYDRG1A 1050-1052      MNYDRG2A 1053-1055
        MNYDRG3A 1056-1058      MNYDRG4A 1059-1061      MNYDRG5A 1062-1064
        MNYDRG6A 1065-1067      DRUPSET 1068-1069       UPSDRG1A 1070-1072
        UPSDRG2A 1073-1075      UPSDRG3A 1076-1078      UPSDRG4A 1079-1081
        UPSDRG5A 1082-1084      UPSDRG6A 1085-1087      DRLSWORK 1088-1089
        LSWDRG1A 1090-1092      LSWDRG2A 1093-1095      LSWDRG3A 1096-1098
        LSWDRG4A 1099-1101      LSWDRG5A 1102-1104      LSWDRG6A 1105-1107
        DRSUSPIC 1108-1109      SSPDRG1A 1110-1112      SSPDRG2A 1113-1115
        SSPDRG3A 1116-1118      SSPDRG4A 1119-1121      SSPDRG5A 1122-1124
        SSPDRG6A 1125-1127      DRTRBLAW 1128-1129      LAWDRG1A 1130-1132
        LAWDRG2A 1133-1135      LAWDRG3A 1136-1138      LAWDRG4A 1139-1141
        LAWDRG5A 1142-1144      LAWDRG6A 1145-1147      DRNOTEAT 1148-1149
        NETDRG1A 1150-1152      NETDRG2A 1153-1155      NETDRG3A 1156-1158
        NETDRG4A 1159-1161      NETDRG5A 1162-1164      NETDRG6A 1165-1167
        DRCOPE 1168-1169        CPEDRG1A 1170-1172      CPEDRG2A 1173-1175
        CPEDRG3A 1176-1178      CPEDRG4A 1179-1181      CPEDRG5A 1182-1184
        CPEDRG6A 1185-1187      DREMGMED 1188-1189      EMDRG1A 1190-1192
        EMDRG2A 1193-1195       EMDRG3A 1196-1198       EMDRG4A 1199-1201
        EMDRG5A 1202-1204       EMDRG6A 1205-1207       AS14READ 1208-1209
        HLPQTCIG 1210-1211      HLPALCHO 1212-1213      HLPDRUSE 1214-1215
        TRTER 1216-1217         TRTHOSP 1218-1219       TRTPDOC 1220-1221
        TRTREH 1222-1223        TRTMHF 1224-1225        TRTSHELP 1226-1227
        TRTOTHER 1228-1229      TRTNONE 1230-1231       TRTNEWA 1232-1233
        TRTNEWB 1234-1235       TRTCALL 1236-1237       TRTCALLO 1238-1239
        TRTDRGYR 1240-1241      TRTPRBYR 1242-1243      RSKPKCIG 1244-1245
        RSKMJOCC 1246-1247      RSKMJREG 1248-1249      RKTRYPCP 1250-1251
        RKPCPREG 1252-1253      RKTRYHER 1254-1255      RKHERREG 1256-1257
        RKTRYCOC 1258-1259      RKCOCOCC 1260-1261      RKCOCREG 1262-1263
        RK2DRINK 1264-1265      RK5DRINK 1266-1267      RSKBINGE 1268-1269
        SEX 1270                BIRMON 1271-1272        BIRYEAR 1273-1276
        MARITAL 1277-1278       NOMARR 1279-1280        WORKSTAT 1281-1282
        PAYYR 1283-1284         PAYMO 1285-1286         ROCCUP1 1287-1288
        BUSINES1 1289-1290      NO5JOB 1291-1292        CWE 1293-1294
        FULLPART 1295-1296      CWEOCC1 1297-1298       CWEBUS1 1299-1300
        EDUC 1301-1302          STUDENT 1303-1304       SCHDAYS 1305-1306
        SKIPPED 1307-1308       WORKDAYS 1309-1310      WORKBLAH 1311-1312
        MILES 1313-1317         ACCID 1318-1319         NOCHILD 1320-1321
        CHAGE1 1322             CHAGE2 1323             CHAGE3 1324
        CHAGE4 1325             CHAGE5 1326             CHAGE6 1327
        CHAGE7 1328             CHAGE8 1329             CHAGE9 1330-1331
        CHAGE10 1332-1333       TOTPEOP 1334-1335       MOTHER 1336-1337
        FATHER 1338-1339        SPOUSE 1340-1341        INLAW 1342-1343
        OWNCHILD 1344-1345      STEPCHLD 1346-1347      BROSIS 1348-1349
        OTHREL 1350-1351        FRIENDS 1352-1353       OTHERNON 1354-1355
        SERVICE 1356-1357       MILSTAT 1358-1359       MILYR1A 1360-1361
        MILYR2A 1362-1363       MILYR3A 1364-1365       MILYR4A 1366-1367
        MILYR5A 1368-1369       MILYR6A 1370-1371       YRENTS 1372-1373
        VIETNAM 1374-1375       DORM 1376-1377          MILBASE 1378-1379
        HOSP 1380-1381          TELNO 1382-1383         MOVES 1384-1385
        INCOME 1386-1387        INTDATE 1388-1391       EIIDATE 1392
        INTMONTH 1393-1394      PARQ 1395-1396          UNDINT 1397-1398
        COOPINT 1399-1400       PRIVACY 1401-1402       PPRES 1403-1404
        SPRES 1405-1406         PARPRES 1407-1408       OARPRES 1409-1410
        OAPRES 1411-1412        CPRES 1413-1414         OPRES 1415-1416
        POPDEN 1417             REGION 1418             DIVISION 1419
        EIBDATE 1420            IRAGE 1421-1422         IIAGE 1423
        IRSEX 1424              IISEX 1425              IRRACE 1426
        IIRACE 1427             IRHOIND 1428            IIHOIND 1429
        IRHOGRP 1430-1431       IIHOGRP 1432            IRHOGRP2 1433-1434
        IIHOGRP2 1435           IRMARIT 1436-1437       IIMARIT 1438
        IREDUC 1439-1440        IIEDUC 1441             IRWORKST 1442-1443
        IIWORKST 1444           IRALCRC 1445            IIALCRC 1446
        IRMJRC 1447             IIMJRC 1448             IRCOCRC 1449
        IICOCRC 1450            IRSEDRC 1451            IISEDRC 1452
        IRTRNRC 1453            IITRNRC 1454            IRSTMRC 1455
        IISTMRC 1456            IRANLRC 1457            IIANLRC 1458
        IRCIGRC 1459            IICIGRC 1460            IRINHRC 1461
        IIINHRC 1462            IRHALRC 1463            IIHALRC 1464
        IRHERRC 1465            IIHERRC 1466            IRPCPRC 1467
        IIPCPRC 1468            IRALCFQ 1469            IIALCFQ 1470
        IRMJFQ 1471-1472        IIMJFQ 1473             IRCOCFQ 1474
        IICOCFQ 1475            CATAGE 1476             CATAG2 1477
        RACE 1478               EDUCCAT2 1479           EMPSTAT2 1480
        CIGFLAG 1481            CIGYR 1482              CIGMON 1483
        ALCFLAG 1484            ALCYR 1485              ALCMON 1486
        SEDFLAG 1487            SEDYR 1488              SEDMON 1489
        TRQFLAG 1490            TRQYR 1491              TRQMON 1492
        STMFLAG 1493            STMYR 1494              STMMON 1495
        ANLFLAG 1496            ANLYR 1497              ANLMON 1498
        MRJFLAG 1499            MRJYR 1500              MRJMON 1501
        INHFLAG 1502            INHYR 1503              INHMON 1504
        COCFLAG 1505            COCYR 1506              COCMON 1507
        HALFLAG 1508            HALYR 1509              HALMON 1510
        PCPFLAG 1511            PCPYR 1512              PCPMON 1513
        HERFLAG 1514            HERYR 1515              HERMON 1516
        PSYFLAG2 1517           PSYYR2 1518             PSYMON2 1519
        SUMFLAG 1520            SUMYR 1521              SUMMON 1522
        MJOFLAG 1523            MJOYR2 1524             MJOMON2 1525
        IEMFLAG 1526            IEMYR 1527              IEMMON 1528
        ALCDLYF 1529            ALCWKF 1530             ALCMONF 1531
        ALCOCCF 1532            ALCYRF 1533             MRJDLYF 1534
        MRJWKF 1535             MRJMONF 1536            MRJOCCF 1537
        MRJYRF 1538             COCDLYF 1539            COCWKF 1540
        COCMONF 1541            COCOCCF 1542            COCYRF 1543
        ANALWT 1544-1554 .4     VEREP 1555              VESTR 1556-1559
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   RESPID  = 'RESPONDENT IDENTIFICATION NUMBER'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (PSU)'
   CIGTRY  = 'AGE WHEN FIRST TRIED A CIGARETTE'
   CIG5PK  = 'SMOKED 5 OR MORE PACKS OF CIGARETTES IN'
   CIGREC  = 'MOST RECENT TIME SMOKED A CIGARETTE'
   AVCIG   = '# CIGARETTES SMOKED PER DAY LAST 30 DAYS'
   CIGINT  = 'TYPE OF TIME REPORTED IN CIGTIME'
   CIGTIME = 'NUMBER OF INTERVALS (CIGINT) R HAS SMOKE'
   CIGAGE  = 'AGE WHEN FIRST STARTED SMOKING DAILY'
   CIGYRS  = '# YEARS SMOKED DAILY'
   PACKS   = '# CIGARETTES SMOKED DAILY'
   OTHTOB  = '# TIMES USED SMOKELESS TOBACCO PAST 12 M'
   ADDALC  = 'R THINKS ALCOHOL ADDITIVE'
   ADDMJ   = 'R THINKS MARIJUANA ADDICTIVE'
   ADDSED  = 'R THINKS SEDATIVES ADDICTIVE'
   ADDTRAN = 'R THINKS TRANQUILIZERS ADDICTIVE'
   ADDAMP  = 'R THINKS AMPHETAMINES ADDICTIVE'
   ADDCOC  = 'R THINKS COCAINE ADDICTIVE'
   ADDLSD  = 'R THINKS LSD ADDICTIVE'
   ADDHER  = 'R THINKS HEROIN ADDICTIVE'
   ADDCIG  = 'R THINKS CIGARETTES ADDICTIVE'
   ADDNONE = 'R THINKS NONE OF THESE ARE ADDICTIVE'
   ADDALL  = 'R THINKS ALL OF THESE ARE ADDICTIVE'
   ALCTRY  = 'AGE WHEN HAD FIRST DRINK OF ALCOHOL'
   ALCREC  = 'MOST RECENT ALCOHOL DRINK'
   ALCPREF = 'USUAL ALCOHOL BEVERAGE'
   ALCDAYS = '# OF DAYS DRANK ALCOHOL PAST 30 DAYS'
   NODR30A = 'USUAL # DRINKS PER DAY PAST 30 DAYS'
   MODR30A = 'MOST # DRINKS ON ONE DAY IN PAST 30 DAYS'
   MODR30DY= '# DAYS DRANK AMOUNT IN A-6 PAST 30 DAYS'
   DR5DAY  = '# DAYS DRANK 5 OR MORE DRINKS PAST 30 DA'
   ALCAGE  = 'AGE BEGAN DRINKING ALCOHOL MONTHLY OR MO'
   ALCPAT  = 'FREQUENCY ALCOHOL CONSUMPTION PAST 12 MO'
   DRUNKYR = '# TIMES DRUNK ON ALCOHOL PAST 12 MONTHS'
   ALCSED  = 'SEDATIVES USED W/ALCOHOL PAST 12 MONTHS'
   ALCTRAN = 'TRANQUILIZERS USED W/ALCOHOL PAST 12 MON'
   ALCSTM  = 'STIMULANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCANAL = 'ANALGESICS USED W/ALCOHOL PAST 12 MONTHS'
   ALCMJ   = 'MARIJUANA USED W/ALCOHOL PAST 12 MONTHS'
   ALCINH  = 'INHALANTS USED W/ALCOHOL PAST 12 MONTHS'
   ALCCOC  = 'COCAINE USED W/ALCOHOL PAST 12 MONTHS'
   ALCHAL  = 'HALLUCINOGENS USED W/ALCOHOL PAST 12 MON'
   ALCOPT  = 'OPIATES USED W/ALCOHOL PAST 12 MONTHS'
   ALCNONE = 'NONE OF LISTED DRUGS USED W/ALCOHOL IN P'
   NOSEDAT = 'HAS NEVER TAKEN SEDATIVES FOR NONMEDICAL'
   BUTISOL = 'BUTISOL EVER TAKEN FOR NONMEDICAL REASON'
   BUTICAPS= 'BUTICAPS EVER TAKEN FOR NONMEDICAL REASO'
   AMYTAL  = 'AMYTAL EVER TAKEN FOR NONMEDICAL REASONS'
   ESKABARB= 'ESKABARB EVER TAKEN FOR NONMEDICAL REASO'
   LUMINAL = 'LUMINAL EVER TAKEN FOR NONMEDICAL REASON'
   MEBARAL = 'MEBARAL EVER TAKEN FOR NONMEDICAL REASON'
   AMOBARB = 'AMOBARBITAL EVER TAKEN FOR NONMEDICAL RE'
   PHENOBAR= 'PHENOBARBITAL EVER TAKEN FOR NONMEDICAL'
   ALURATE = 'ALURATE EVER TAKEN FOR NONMEDICAL REASON'
   PLACIDYL= 'PLACIDYL EVER TAKEN FOR NONMEDICAL REASO'
   DORIDEN = 'DORIDEN EVER TAKEN FOR NONMEDICAL REASON'
   NOLUDAR = 'NOLUDAR EVER TAKEN FOR NONMEDICAL REASON'
   SOPOR   = 'SOPOR EVER TAKEN FOR NONMEDICAL REASONS'
   QUAALUDE= 'QUAALUDE EVER TAKEN FOR NONMEDICAL REASO'
   PAREST  = 'PAREST EVER TAKEN FOR NONMEDICAL REASONS'
   NOCTEC  = 'NOCTEC EVER TAKEN FOR NONMEDICAL REASONS'
   METHAQ  = 'METHAQUALONE EVER TAKEN FOR NONMEDICAL R'
   CHHYD   = 'CHLORAL HYDRATE EVER TAKEN FOR NONMEDICA'
   NEMBUTAL= 'NEMBUTAL EVER TAKEN FOR NONMEDICAL REASO'
   CARBTAL = 'CARBITROL EVER TAKEN FOR NONMEDICAL REAS'
   SECONAL = 'SECONAL EVER TAKEN FOR NONMEDICAL REASON'
   TUINAL  = 'TUINAL EVER TAKEN FOR NONMEDICAL REASONS'
   PENTOB  = 'PENTOBARBITAL EVER TAKEN FOR NONMEDICAL'
   SECOB   = 'SECOBARBITAL EVER TAKEN FOR NONMEDICAL R'
   DALMANE = 'DALMANE EVER TAKEN FOR NONMEDICAL REASON'
   SEDDKNAM= 'NOT SURE/DON''T KNOW'
   SEDOTH  = 'OTHER SEDATIVE (1ST RESPONSE)'
   SEDNEWA = 'OTHER SEDATIVE EVER USED (FIRST MENTION)'
   SEDNEWB = 'OTHER SEDATIVE EVER USED (SECOND MENTION'
   SEDNEWC = 'OTHER SEDATIVE EVER USED (THIRD MENTION)'
   SEDAGE  = 'AGE FIRST TOOK SEDATIVE FOR NONMEDICAL R'
   SEDTOT  = '# TIMES EVER TOOK SEDATIVE FOR NONMEDICA'
   SEDREC  = 'MOST RECENT TIME USED SEDATIVE FOR NONME'
   SEDALC  = 'ALCOHOL USED WITH SEDATIVES PAST 12 MONT'
   SEDTR   = 'TRANQUILIZERS USED WITH SEDATIVES PAST 1'
   SEDST   = 'STIMULANTS USED WITH SEDATIVES PAST 12 M'
   SEDAN   = 'ANALGESICS USED WITH SEDATIVES PAST 12 M'
   SEDMJ   = 'MARIJUANA USED WITH SEDATIVES PAST 12 MO'
   SEDINH  = 'INHALANTS USED WITH SEDATIVES PAST 12 MO'
   SEDCOC  = 'COCAINE USED WITH SEDATIVES PAST 12 MONT'
   SEDHAL  = 'HALLUCINOGENS USED WITH SEDATIVES PAST 1'
   SEDOPT  = 'OPIATES USED WITH SEDATIVES PAST 12 MONT'
   SEDNONE = 'NONE OF THESE USED WITH SEDATIVES PAST 1'
   AS3READ = 'TRANQUILIZERS - READING PREFERENCE'
   NOTRANQ = 'HAS NEVER TAKEN TRANQUILIZER FOR NONMED'
   VALIUM  = 'VALIUM EVER TAKEN FOR NONMEDICAL REASONS'
   LIBRIUM = 'LIBRIUM EVER TAKEN FOR NONMEDICAL REASON'
   LIBTAB  = 'LIBRITABS EVER TAKEN FOR NONMEDICAL REAS'
   SKLY    = 'SK-LYGEN EVER TAKEN FOR NONMEDICAL REASO'
   SERAX   = 'SERAX EVER TAKEN FOR NONMEDICAL REASONS'
   TRANXENE= 'TRANXENE EVER TAKEN FOR NONMEDICAL REASO'
   ATIVAN  = 'ATIVAN EVER TAKEN FOR NONMEDICAL REASONS'
   VERSTRAN= 'VERSTRAN EVER TAKEN FOR NONMEDICAL REASO'
   MEPRSPAN= 'MEPROSPAN EVER TAKEN FOR NONMEDICAL REAS'
   MILTOWN = 'MILTOWN EVER TAKEN FOR NONMEDICAL REASON'
   EQUANIL = 'EQUANIL EVER TAKEN FOR NONMEDICAL REASON'
   MEPROB  = 'MEPROBAMATE EVER TAKEN FOR NONMEDICAL RE'
   VISTAR  = 'VISTARIL EVER TAKEN FOR NONMEDICAL REASO'
   ATARAX  = 'ATARAX EVER TAKEN FOR NONMEDICAL REASONS'
   BENADRYL= 'BENADRYL EVER TAKEN FOR NONMEDICAL REASO'
   XANAX   = 'XANAX EVER TAKEN FOR NONMEDICAL REASONS'
   TRDKNAM = 'NOT SURE'
   TROTH   = 'OTHER TRANQUILIZER SPECIFIED'
   TRNEWA  = 'OTHER TRANQUILIZER EVER USED (FIRST MENT'
   TRNEWB  = 'OTHER TRANQUILIZER EVER USED (SECOND MEN'
   TRNEWC  = 'OTHER TRANQUILIZER EVER USED (THIRD MENT'
   TRANAGE = 'AGE FIRST TOOK TRANQUILIZER FOR NONMEDIC'
   TRANTOT = '# TIMES EVER TOOK TRANQUILIZER NONMEDICA'
   TRANREC = 'MOST RECENT TIME USED TRANQUILIZER NONME'
   TRALC   = 'ALCOHOL USED WITH TRANQUILIZERS PAST 12'
   TRSED   = 'SEDATIVES USED WITH TRANQUILIZERS PAST 1'
   TRSTM   = 'STIMULANTS USED WITH TRANQUILIZERS PAST'
   TRANAL  = 'ANALGESICS USED WITH TRANQUILIZERS PAST'
   TRMJ    = 'MARIJUANA USED WITH TRANQUILIZERS PAST 1'
   TRINH   = 'INHALANTS USED WITH TRANQUILIZERS PAST 1'
   TRCOC   = 'COCAINE USED WITH TRANQUILIZERS PAST 12'
   TRHAL   = 'HALLUCINOGENS USED WITH TRANQUILIZERS PA'
   TROPT   = 'OPIATES USED WITH TRANQUILIZERS PAST 12'
   TRNONE  = 'NONE OF THESE USED WITH TRANQUILIZERS PS'
   AS4READ = 'STIMULANTS - READING PREFERENCE'
   NOSTIMS = 'HAS NEVER TAKEN STIMULANT FOR NONMEDICAL'
   DEXED   = 'DEXEDRINE EVER TAKEN FOR NONMEDICAL REAS'
   DEXAMYL = 'DEXAMYL EVER TAKEN FOR NONMEDICAL REASON'
   ESKAT   = 'ESKATROL EVER TAKEN FOR NONMEDICAL REASO'
   BENZ    = 'BENZEDRINE EVER TAKEN FOR NONMEDICAL REA'
   BIPHET  = 'BIPHETAMINE EVER TAKEN FOR NONMEDICAL RE'
   DESOXYN = 'DESOXYN EVER TAKEN FOR NONMEDICAL REASON'
   DETAMP  = 'DEXTROAMPHETAMINE EVER TAKEN FOR NONMED'
   METHI   = 'METHEDRINE EVER TAKEN FOR NONMEDICAL REA'
   OBLA    = 'OBEDRIN-L.A. EVER TAKEN FOR NONMEDICAL R'
   TENUATE = 'TENUATE EVER TAKEN FOR NONMEDICAL REASON'
   TEPANIL = 'TEPANIL EVER TAKEN FOR NONMEDICAL REASON'
   DIDREX  = 'DIDREX EVER TAKEN FOR NONMEDICAL REASONS'
   PLEGINE = 'PLEGINE EVER TAKEN FOR NONMEDICAL REASON'
   PRELUDIN= 'PRELUDIN EVER TAKEN FOR NONMEDICAL REASO'
   PRESATE = 'PRE-SATE EVER TAKEN FOR NONMEDICAL REASO'
   IONAMIN = 'IONAMIN EVER TAKEN FOR NONMEDICAL REASON'
   PONDIMIN= 'PONDIMIN EVER TAKEN FOR NONMEDICAL REASO'
   VORANIL = 'VORANIL EVER TAKEN FOR NONMEDICAL REASON'
   SANOREX = 'SANOREX EVER TAKEN FOR NONMEDICAL REASON'
   RITALIN = 'RITALIN EVER TAKEN FOR NONMEDICAL REASON'
   CYLERT  = 'CYLERT EVER TAKEN FOR NONMEDICAL REASONS'
   STMDKNAM= 'NOT SURE'
   STIMOR  = 'OTHER STIMULANT SPECIFIED'
   STIMNEWA= 'OTHER STIMULANT EVER USED (FIRST MENTION'
   STIMNEWB= 'OTHER STIMULANT EVER USED (SECOND MENTIO'
   STIMNEWC= 'OTHER STIMULANT EVER USED (THIRD MENTION'
   STIMAGE = 'AGE FIRST TOOK STIMULANT FOR NONMEDICAL'
   STIMTOT = '# TIMES EVER TOOK STIMULANT FOR NONMEDIC'
   STIMREC = 'MOST RECENT TIME USED STIMULANT FOR NONM'
   STALC   = 'ALCOHOL USED WITH STIMULANTS PAST 12 MON'
   STSED   = 'SEDATIVES USED WITH STIMULANTS PAST 12 M'
   STTRAN  = 'TRANQUILIZERS USED WITH STIMULANTS PAST'
   STANAL  = 'ANALGESICS USED WITH STIMULANTS PAST 12'
   STMJ    = 'MARIJUANA USED WITH STIMULANTS PAST 12 M'
   STINH   = 'INHALANTS USED WITH STIMULANTS PAST 12 M'
   STCOC   = 'COCAINE USED WITH STIMULANTS PAST 12 MON'
   STHAL   = 'HALLUCINOGENS USED WITH STIMULANTS PAST'
   STOPT   = 'OPIATES USED WITH STIMULANTS PAST 12 MON'
   STNONE  = 'NONE OF THESE USED WITH STIMULANTS PAST'
   AS5READ = 'ANALGESICS - READING PREFERENCE'
   ANALNONE= 'HAS NEVER TAKEN ANALGESICS FOR NONMEDICA'
   DARVON  = 'DARVON EVER TAKEN FOR NONMEDICAL REASONS'
   DOLENE  = 'DOLENE EVER TAKEN FOR NONMEDICAL REASONS'
   SK65A   = 'SK-65 EVER TAKEN FOR NONMEDICAL REASONS'
   PROPOXY = 'PROPOXYPHENE EVER TAKEN FOR NONMEDICAL R'
   LERITINE= 'LERITINE EVER TAKEN FOR NONMEDICAL REASO'
   LEVODRO = 'LEVO-DROMORAN EVER TAKEN FOR NONMEDICAL'
   PERCODAN= 'PERCODAN EVER TAKEN FOR NONMEDICAL REASO'
   DEMEROL = 'DEMEROL EVER TAKEN FOR NONMEDICAL REASON'
   DILAUD  = 'DILAUDID EVER TAKEN FOR NONMEDICAL REASO'
   TYLCOD  = 'TYLENOL W/CODEINE EVER TAKEN FOR NONMEDI'
   CODEINE = 'CODEINE EVER TAKEN FOR NONMEDICAL REASON'
   DOLOP   = 'DOLOPHINE EVER TAKEN FOR NONMEDICAL REAS'
   WESTOD  = 'WESTODONE EVER TAKEN FOR NONMEDICAL REAS'
   METHDON = 'METHADONE EVER TAKEN FOR NONMEDICAL REAS'
   TALWIN  = 'TALWIN EVER TAKEN FOR NONMEDICAL REASONS'
   ANLDKNAM= 'NOT SURE'
   ANALOTH = 'OTHER RESPONSE SPECIFIED'
   ANALNEWA= 'OTHER ANALGESIC EVER USED (FIRST MENTION'
   ANALNEWB= 'OTHER ANALGESIC EVER USED (SECOND MENTIO'
   ANALNEWC= 'OTHER ANALGESIC EVER USED (THIRD MENTION'
   ANALAGE = 'AGE FIRST TOOK ANALGESIC FOR NONMEDICAL'
   ANALTOT = '# TIMES EVER TOOK ANALGESIC FOR NONMEDIC'
   ANALREC = 'MOST RECENT TIME USED ANALGESIC NONMEDIC'
   ANLALC  = 'ALCOHOL USED WITH ANALGESICS PAST 12 MON'
   ANLSED  = 'SEDATIVES USED WITH ANALGESICS PAST 12 M'
   ANLTRAN = 'TRANQUILIZERS USED WITH ANALGESICS PAST'
   ANLSTM  = 'STIMULANTS USED WITH ANALGESICS PAST 12'
   ANLMJ   = 'MARIJUANA USED WITH ANALGESICS PAST 12 M'
   ANLINH  = 'INHALANTS USED WITH ANALGESICS PAST 12 M'
   ANLCOC  = 'COCAINE USED WITH ANALGESICS PAST 12 MON'
   ANLHAL  = 'HALLUCINOGENS USED WITH ANALGESICS PAST'
   ANLOPT  = 'OPIATES USED WITH ANALGESICS PAST 12 MON'
   ANLNONE = 'NONE OF THESE USED WITH ANALGESICS PAST'
   MJOPP   = 'AGE AT FIRST CHANCE TO TRY MARIJUANA/HAS'
   MJAGE   = 'AGE WHEN FIRST USED MARIJUANA/HASH'
   MJTOT   = '# TIMES USED MARIJUANA/HASH IN LIFE'
   MJREC   = 'MOST RECENT TIME USED MARIJUANA/HASH'
   MJDAY30A= '# DAYS USED MARIJUANA/HASH IN PAST 30 DA'
   MJAV30A = '# JOINTS SMOKED PER DAY IN PAST 30 DAYS'
   MJAMT30A= 'TOTAL AMOUNT MARIJUANA USED PAST 30 DAYS'
   MJDOL   = 'COST OF MARIJUANA USED IN PAST 30 DAYS'
   MJALC30A= 'HOW OFTEN DRANK ALCOHOL WHEN USED MRJ PA'
   MJYRFREQ= 'FREQUENCY USED MARIJUANA PAST 12 MONTHS'
   MJALC   = 'ALCOHOL USED WITH MARIJUANA PAST 12 MONT'
   MJSED   = 'SEDATIVES USED WITH MARIJUANA PAST 12 MO'
   MJTRAN  = 'TRANQUILIZERS USED WITH MARIJUANA PAST 1'
   MJSTM   = 'STIMULANTS USED WITH MARIJUANA PAST 12 M'
   MJANAL  = 'ANALGESICS USED WITH MARIJUANA PAST 12 M'
   MJINH   = 'INHALANTS USED WITH MARIJUANA PAST 12 MO'
   MJCOC   = 'COCAINE USED WITH MARIJUANA PAST 12 MONT'
   MJHAL   = 'HALLUCINOGENS USED WITH MARIJUANA PAST 1'
   MJOPT   = 'OPIATES USED WITH MARIJUANA PAST 12 MONT'
   MJNONE  = 'NONE OF THESE USED WITH MARIJUANA PAST 1'
   AS7READ = 'INHALANTS - READING PREFERENCE'
   INHNONE = 'AGE WHEN FIRST USED AN INHALANT'
   GAS     = 'EVER INHALED GASOLINE OR LIGHTER FLUIDS'
   SPPAINT = 'EVER INHALED SPRAY PAINTS'
   AEROS   = 'EVER INHALED OTHER AEROSOL SPRAYS'
   GLUE    = 'EVER INHALED SHOE SHINE LIQUID/GLUE/TOLU'
   SOLVENT = 'EVER INHALED LACQUER THINNER/PAINT SOLVE'
   AMYLNIT = 'EVER INHALED AMYL NITRITE/LOCKER RM ODOR'
   ETHER   = 'EVER INHALED HALOTHANE/ETHER/OTHER ANEST'
   NITOXID = 'EVER INHALED NITROUS OXIDE/WHIPPETS'
   CLEFLU  = 'EVER INHALED CORRECTION FLD/DEGREASER/CL'
   OTHINHL = 'OTHER RESPONSE SPECIFIED'
   INHNEWA = 'OTHER SUBSTANCE EVER INHALED'
   GAS30A  = 'INHALED GASOLINE OR LIGHTER FLUIDS PAST'
   SPPAN30A= 'INHALED SPRAY PAINTS PAST 30 DAYS'
   AEROS30A= 'INHALED OTHER AEROSOL SPRAYS PAST 30 DAY'
   GLUE30A = 'INHALED SHOE SHINE LIQUID/GLUE/TOLUENE P'
   SOLVN30A= 'INHALED LACQUER THINNER/PAINT SOLVENTS P'
   AMLNT30A= 'INHALED AMYL NITRITE/LOCKER RM ODORIZER'
   ETHER30A= 'INHALED HALOTHANE/ETHER/OTH ANESTHETICS'
   NOX30A  = 'INHALED NITROUS OXIDE/WHIPPETS PAST 30 D'
   CLFL30A = 'INHALED CORRECTION FLD/DEGREASER/CLN FLD'
   INHOT30A= 'OTHER INHALANT SPECIFIED - 1ST MENTION'
   INH30NO = 'DID NOT USE ANY INHALANT PAST 30 DAYS'
   INHTOT  = '# TIMES USED INHALANT IN LIFETIME'
   INHREC  = 'MOST RECENT TIME USED INHALANT'
   INHDY30A= '# DAYS USED AN INHALANT IN PAST 30 DAYS'
   INHEFF  = 'USUAL AMOUNT (EFFECTS) OF INHALANTS USED'
   INHPO   = 'EVER PASSED OUT FROM USING INHALANTS'
   INHQNC  = 'WHICH QUESTIONS WERE NOT CLEAR'
   INHANSY = 'ANSWER MARKED FOR EACH QUESTION'
   AS8READ = 'ANSWER SHEET #8 - READING PREFERENCE'
   COCOPP  = 'AGE AT FIRST CHANCE TO TRY COCAINE'
   COCAGE  = 'AGE WHEN FIRST USED COCAINE'
   COCTOT  = '# TIMES USED COCAINE IN LIFE'
   COCREC  = 'MOST RECENT TIME USED COCAINE (IN ANY FO'
   COCUS30A= '# DAYS USED COCAINE PAST 30 DAYS'
   COCAM30A= '# OF GRAMS OF COCAINE USED IN PAST 30 DA'
   COCBUCK = '$ AMOUNT SPENT ON COCAINE USED IN PAST 3'
   COC30ALC= 'HOW OFTEN USED ALCOHOL WITH COCAINE PAST'
   COCYRFRQ= 'FREQUENCY USED COCAINE PAST 12 MONTHS'
   COCALC  = 'ALCOHOL USED WITH COCAINE PAST 12 MONTHS'
   COCSED  = 'SEDATIVES USED WITH COCAINE PAST 12 MONT'
   COCTRAN = 'TRANQUILIZERS USED WITH COCAINE PAST 12'
   COCSTM  = 'STIMULANTS USED WITH COCAINE PAST 12 MON'
   COCANAL = 'ANALGESICS USED WITH COCAINE PAST 12 MON'
   COCMJ   = 'MARIJUANA USED WITH COCAINE PAST 12 MONT'
   COCINH  = 'INHALANTS USED WITH COCAINE PAST 12 MONT'
   COCHAL  = 'HALLUCINOGENS USED WITH COCAINE PAST 12'
   COCOPT  = 'OPIATES USED WITH COCAINE PAST 12 MONTHS'
   COCNONE = 'NONE OF THESE USED WITH COCAINE PAST 12'
   COCSNIFX= 'SNIFFED/SNORTED COCAINE THRU NOSE'
   COCSWALX= 'SWALLOWED/DRANK COCAINE'
   COCIVX  = 'INJECTED COCAINE WITH A NEEDLE'
   FREEBASX= 'SMOKED/FREE-BASED COCAINE'
   COCOTHX = 'OTHER METHOD SPECIFIED'
   AS9READ = 'HALLUCINOGENS - READING PREFERENCE'
   HALLQCL = 'DID YOU UNDERSTAND THE LAST THREE QUESTI'
   HALLOPP = 'AGE AT FIRST CHANCE TO TRY HALLUCINOGEN'
   HALLAGE = 'AGE WHEN FIRST USED LSD/PCP/OTHER HALLUC'
   HALLTOT = '# TIMES USED LSD/PCP/OTHER HALLUCINOGEN'
   HALLREC = 'MOST RECENT TIME USED HALLUCINOGEN'
   HAL30USE= '# DAYS USED HALLUCINOGEN PAST 30 DAYS'
   LSD     = 'EVER USED LSD'
   PEYOTE  = 'EVER USED PEYOTE'
   MESC    = 'EVER USED MESCALINE'
   PSILCY  = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   PCP     = 'EVER USED PCP (ANGEL DUST)'
   HALLOTH = 'OTHER HALLUCINOGEN SPECIFIED'
   HALNEWA = 'OTHER HALLUCINOGEN EVER USED (1ST MENTIO'
   HALNEWB = 'OTHER HALLUCINOGEN EVER USED (2ND MENTIO'
   PCPREC  = 'MOST RECENT TIME USED PCP'
   PCPFLASH= 'HAD FLASHBACKS FROM USING PCP'
   PCPSENSE= 'HAD TROUBLE SEEING OR HEARING ON PCP'
   PCPFEELV= 'FELT VIOLENT ON PCP'
   PCPACTV = 'DID SOMETHING VIOLENT OR AGGRESSIVE ON P'
   PCPOTH  = 'OTHER REACTION TO PCP SPECIFIED'
   PCPNORCT= 'HAD NO/NONE OF THESE REACTIONS TO PCP'
   PCPNEWA = 'OTHER PCP REACTION SPECIFIED - 1ST MENTI'
   PCPNEWB = 'OTHER PCP REACTION SPECIFIED - 2ND MENTI'
   AS10READ= 'HEROIN - READING PREFERENCE'
   HEROPP  = 'AGE AT FIRST CHANCE TO TRY HEROIN'
   HERAGE  = 'AGE WHEN FIRST USED HEROIN'
   HERTOT  = '# TIMES USED HEROIN IN LIFE'
   HERREC  = 'MOST RECENT TIME USED HEROIN'
   HER30USE= '# DAYS USED HEROIN PAST 30 DAYS'
   HERNEEDL= 'EVER USED HEROIN WITH A NEEDLE'
   HIGHBP  = 'EVER DIAGNOSED AS HAVING HIGH BLOOD PRES'
   BPMED   = 'MEDICATION EVER PRESCRIBED FOR HIGH BLOO'
   WALKPAIN= 'EVER HAD PAIN IN CHEST FROM EXERTION'
   TIMEPAIN= 'EVER HAD SEVERE CHEST PAIN LASTING 1/2 H'
   UPSHOR  = 'EVER HAD SHORTNESS OF BREATH FROM EXERTI'
   ASTHMA  = 'EVER DIAGNOSED AS HAVING LUNG/CHEST COND'
   TRPSYCH = 'EVER TREATED FOR PSYCHOLOGICAL/EMOTIONAL'
   HEART   = 'EVER DIAGNOSED AS HAVING HEART CONDITION'
   FLU     = 'GET BAD COLD OR FLU EVERY YEAR'
   ALLERG  = 'HAS HAY FEVER'
   HOSPYR  = 'HOSPITALIZED OVERNIGHT FOR INJURY/ILLNES'
   SOREYR  = 'HAD SORE THROAT LASTING 3 OR MORE DAYS I'
   RUNNYYR = 'HAD RUNNY NOSE LASTING 3 OR MORE DAYS IN'
   COUGHYR = 'HAD COUGH LASTING ABOUT A WK 3/MORE TIME'
   PHLEGMYR= 'HAD COUGH W/PHLEGM LASTING 3 OR MORE WEE'
   HEALTHYR= 'HEALTH FOR PAST 12 MONTHS'
   FELTGOOD= 'I FELT I WAS AS GOOD AS OTHER PEOPLE'
   FELTMIND= 'I HAD TROUBLE KEEPING MY MIND ON WHAT I'
   FELTDEP = 'I FELT DEPRESSED'
   FELTEFF = 'I FELT EVERYTHING WAS AN EFFORT'
   FELTHOPE= 'I FELT HOPEFUL ABOUT THE FUTURE'
   FELTSLEP= 'MY SLEEP WAS RESTLESS'
   FELTHAP = 'I FELT HAPPY'
   FELTUNF = 'PEOPLE WERE UNFRIENDLY'
   FELTENJ = 'I ENJOYED LIFE'
   FELTCRY = 'I HAD CRYING SPELLS'
   FELTDISL= 'I FELT THAT PEOPLE DISLIKED ME'
   FELTNOGO= 'I COULD NOT GET GOING'
   AS11READ= 'DRUGS - READING PREFERENCE'
   NODRUGS = 'NEVER USED CIGARETTES, ALCOHOL OR ANY OF'
   CDCIGX  = 'TRIED TO CUT DOWN ON USE OF CIGARETTES'
   CDALCX  = 'TRIED TO CUT DOWN ON USE OF ALCOHOL'
   CDSEDX  = 'TRIED TO CUT DOWN ON USE OF SEDATIVES'
   CDTRANX = 'TRIED TO CUT DOWN ON USE OF TRANQUILIZER'
   CDSTMX  = 'TRIED TO CUT DOWN ON USE OF STIMULANTS'
   CDANALX = 'TRIED TO CUT DOWN ON USE OF ANALGESICS'
   CDMJX   = 'TRIED TO CUT DOWN ON USE OF MARIJUANA'
   CDINHX  = 'TRIED TO CUT DOWN ON USE OF INHALANTS'
   CDCOCX  = 'TRIED TO CUT DOWN ON USE OF COCAINE'
   CDHALLX = 'TRIED TO CUT DOWN ON USE OF HALLUCINOGEN'
   CDHERX  = 'TRIED TO CUT DOWN ON USE OF HEROIN'
   CDOTHOPX= 'TRIED TO CUT DOWN ON USE OF OTHER OPIATE'
   CDNONEX = 'DID NOT TRY TO CUT DOWN ON ANY DRUG USED'
   EFFCIGX = 'NEEDED MORE CIGARETTES TO GET SAME EFFEC'
   EFFALCX = 'NEEDED MORE ALCOHOL TO GET SAME EFFECT'
   EFFSEDX = 'NEEDED MORE SEDATIVES TO GET SAME EFFECT'
   EFFTRANX= 'NEEDED MORE TRANQ. TO GET SAME EFFECT'
   EFFSTMX = 'NEEDED MORE STIMULANTS TO GET SAME EFFEC'
   EFFANALX= 'NEEDED MORE ANALGESICS TO GET SAME EFFE'
   EFFMJX  = 'NEEDED MORE MARIJUANA TO GET SAME EFFECT'
   EFFINHX = 'NEEDED MORE INHALANTS TO GET SAME EFFECT'
   EFFCOCX = 'NEEDED MORE COCAINE TO GET SAME EFFECT'
   EFFHALLX= 'NEEDED MORE HALLUCIN. TO GET SAME EFFECT'
   EFFHERX = 'NEEDED MORE HEROIN TO GET SAME EFFECT'
   EFFOTHOX= 'NEEDED MORE OTHER OPIATES TO GET SAME EF'
   EFFNONEX= 'DID NOT NEED MORE OF ANY DRUG FOR SAME E'
   UDAYCIGX= 'USED CIGARETTES DAILY FOR 2+ WEEKS'
   UDAYALCX= 'USED ALCOHOL DAILY FOR 2+ WEEKS'
   UDAYSEDX= 'USED SEDATIVES DAILY FOR 2+ WEEKS'
   UDAYTRAX= 'USED TRANQUILIZERS DAILY FOR 2+ WEEKS'
   UDAYSTMX= 'USED STIMULANTS DAILY FOR 2+ WEEKS'
   UDAYANAX= 'USED ANALGESICS DAILY FOR 2+ WEEKS'
   UDAYMJX = 'USED MARIJUANA DAILY FOR 2+ WEEKS'
   UDAYINHX= 'USED INHALANTS DAILY FOR 2+ WEEKS'
   UDAYCOCX= 'USED COCAINE DAILY FOR 2+ WEEKS'
   UDAYHALX= 'USED HALLUCINOGENS DAILY FOR 2+ WEEKS'
   UDAYHERX= 'USED HEROIN DAILY FOR 2+ WEEKS'
   UDAYOTHX= 'USED OTHER OPIATES DAILY FOR 2+ WEEKS'
   UDAYNONX= 'DID NOT USE ANY DRUG DAILY FOR 2+ WEEKS'
   DEPCIGX = 'FELT DEPENDENT ON CIGARETTES'
   DEPALCX = 'FELT DEPENDENT ON ALCOHOL'
   DEPSEDX = 'FELT DEPENDENT ON SEDATIVES'
   DEPTRANX= 'FELT DEPENDENT ON TRANQUILIZERS'
   DEPSTMX = 'FELT DEPENDENT ON STIMULANTS'
   DEPANALX= 'FELT DEPENDENT ON ANALGESICS'
   DEPMJX  = 'FELT DEPENDENT ON MARIJUANA'
   DEPINHX = 'FELT DEPENDENT ON INHALANTS'
   DEPCOCX = 'FELT DEPENDENT ON COCAINE'
   DEPHALLX= 'FELT DEPENDENT ON HALLUCINOGENS'
   DEPHERX = 'FELT DEPENDENT ON HEROIN'
   DEPOTHOX= 'FELT DEPENDENT ON OTHER OPIATES'
   DEPNONEX= 'DID NOT FEEL DEPENDENT ON ANY DRUG USED'
   WSCIGX  = 'FELT SICK WHEN CUT DOWN ON CIGARETTES'
   WSALCX  = 'FELT SICK WHEN CUT DOWN ON ALCOHOL'
   WSSEDX  = 'FELT SICK WHEN CUT DOWN ON SEDATIVES'
   WSTRANX = 'FELT SICK WHEN CUT DOWN ON TRANQUILIZERS'
   WSSTMX  = 'FELT SICK WHEN CUT DOWN ON STIMULANTS'
   WSANALX = 'FELT SICK WHEN CUT DOWN ON ANALGESICS'
   WSMJX   = 'FELT SICK WHEN CUT DOWN ON MARIJUANA'
   WSINHX  = 'FELT SICK WHEN CUT DOWN ON INHALANTS'
   WSCOCX  = 'FELT SICK WHEN CUT DOWN ON COCAINE'
   WSHALLX = 'FELT SICK WHEN CUT DOWN ON HALLUCINOGENS'
   WSHERX  = 'FELT SICK WHEN CUT DOWN ON HEROIN'
   WSOTHOPX= 'FELT SICK WHEN CUT DOWN ON OTHER OPIATES'
   WSNONEX = 'DID NOT HAVE WITHDRAWAL SYMPTOMS'
   NOBOOZYR= 'DID NOT USE BEER, WINE, OR LIQUOR IN PAS'
   ALCAGGR = 'FLT AGGRESSIVE OR CROSS WHILE DRINKING P'
   ALCARGUM= 'GOT INTO HEATED ARGUMENT WHILE DRINKING'
   ALCABSNT= 'STAYED OUT OF WORK/SCHOOL DUE TO HANGOVE'
   ALCHIGH = 'HIGH OR LITTLE DRUNK ON JOB OR AT SCHOOL'
   ALCJOB  = 'LOST/NEARLY LOST JOB DUE TO DRINKING PAS'
   ALCMATCD= 'TOLD BY SPOUSE/DATE TO CUT DOWN DRINKING'
   ALCRELCD= 'TOLD BY RELATIVE TO CUT DOWN DRINKING PA'
   ALCFRDCD= 'TOLD BY FRIENDS TO CUT DOWN DRINKING PAS'
   ALCTOSS = 'TOSSED DOWN DRINKS FAST TO GET QUICKER E'
   ALCHOLIC= 'WAS AFRAID MIGHT BE/BECOME AN ALCOHOLIC'
   ALCDRUNK= 'STAYED DRUNK MORE THAN 1 DAY AT A TIME P'
   ALCINTOX= 'COULDN''T STOP DRINKING TILL COMPLETELY'
   ALCREM  = 'COULDN''T REMEM. THINGS DONE WHILE DRINK'
   ALCQUICK= 'HAD QUICK DRINK WHEN NO ONE WAS LOOKING'
   ALCMORN = 'OFTEN HAD A DRINK FIRST THING IN MORNING'
   ALCSHOOK= 'HANDS SHOOK AFTER DRINKING DAY BEFORE IN'
   ALCALONE= 'SOMETIMES GOT HIGH/DRUNK WHILE DRINKING'
   ALCBRKPM= 'KEPT ON DRINKING AFTER PROMISING MYSELF'
   AS13NONE= 'NEVER USED CIGARETTES, ALCOHOL OR DRUGS'
   DRDEPRSS= 'BECAME DEPRESSED/LOST INTEREST DUE TO DR'
   DEPDRG1A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-1S'
   DEPDRG2A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-2N'
   DEPDRG3A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-3R'
   DEPDRG4A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-4T'
   DEPDRG5A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-5T'
   DEPDRG6A= 'DRUG CAUSING DEPRESSION/LOST INTEREST-6T'
   DRARGUM = 'HAD ARGUMNTS W/FAMILY/FRNDS PST YR DUE T'
   ARGDRG1A= 'DRUG CAUSING ARGUMENTS/FIGHTS-1ST MENTIO'
   ARGDRG2A= 'DRUG CAUSING ARGUMENTS/FIGHTS-2ND MENTIO'
   ARGDRG3A= 'DRUG CAUSING ARGUMENTS/FIGHTS-3RD MENTIO'
   ARGDRG4A= 'DRUG CAUSING ARGUMENTS/FIGHTS-4TH MENTIO'
   ARGDRG5A= 'DRUG CAUSING ARGUMENTS/FIGHTS-5TH MENTIO'
   ARGDRG6A= 'DRUG CAUSING ARGUMENTS/FIGHTS-6TH MENTIO'
   DRTRBLE = 'HAD TROUBLE AT SCHOOL OR ON THE JOB'
   TRBDRG1A= '1ST DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   TRBDRG2A= '2ND DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   TRBDRG3A= '3RD DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   TRBDRG4A= '4TH DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   TRBDRG5A= '5TH DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   TRBDRG6A= '6TH DRUG CAUSING TROUBLE AT SCHOOL OR WO'
   DRDRIVE = 'DROVE UNSAFELY'
   DRVDRG1A= '1ST DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRVDRG2A= '2ND DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRVDRG3A= '3RD DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRVDRG4A= '4TH DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRVDRG5A= '5TH DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRVDRG6A= '6TH DRUG MENTIONED CAUSING UNSAFE DRIVIN'
   DRNTRMB = 'COULD NOT REMEMBER'
   NRMDRG1A= '1ST DRUG CAUSING MEMORY LAPSES'
   NRMDRG2A= '2ND DRUG CAUSING MEMORY LAPSES'
   NRMDRG3A= '3RD DRUG CAUSING MEMORY LAPSES'
   NRMDRG4A= '4TH DRUG CAUSING MEMORY LAPSES'
   NRMDRG5A= '5TH DRUG CAUSING MEMORY LAPSES'
   NRMDRG6A= '6TH DRUG CAUSING MEMORY LAPSES'
   DRALONE = 'FELT ALONE/ISOLATED PAST YEAR DUE TO DRU'
   ALNDRG1A= 'DRUG CAUSING FEELING ALONE/ISOLATED-1ST'
   ALNDRG2A= 'DRUG CAUSING FEELING ALONE/ISOLATED-2ND'
   ALNDRG3A= 'DRUG CAUSING FEELING ALONE/ISOLATED-3RD'
   ALNDRG4A= 'DRUG CAUSING FEELING ALONE/ISOLATED-4TH'
   ALNDRG5A= 'DRUG CAUSING FEELING ALONE/ISOLATED-5TH'
   ALNDRG6A= 'DRUG CAUSING FEELING ALONE/ISOLATED-6TH'
   DRANX   = 'FELT NERVOUS/ANXIOUS PAST YEAR DUE TO DR'
   ANXDRG1A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-1ST'
   ANXDRG2A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-2ND'
   ANXDRG3A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-3RD'
   ANXDRG4A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-4TH'
   ANXDRG5A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-5TH'
   ANXDRG6A= 'DRUG CAUSING FEELING NERVOUS/ANXIOUS-6TH'
   DRHEALTH= 'HAD HEALTH PROBLEMS PAST YEAR DUE TO DRU'
   HLTDRG1A= 'DRUG CAUSING HEALTH PROBLEMS-1ST MENTION'
   HLTDRG2A= 'DRUG CAUSING HEALTH PROBLEMS-2ND MENTION'
   HLTDRG3A= 'DRUG CAUSING HEALTH PROBLEMS-3RD MENTION'
   HLTDRG4A= 'DRUG CAUSING HEALTH PROBLEMS-4TH MENTION'
   HLTDRG5A= 'DRUG CAUSING HEALTH PROBLEMS-5TH MENTION'
   HLTDRG6A= 'DRUG CAUSING HEALTH PROBLEMS-6TH MENTION'
   DRNTHINK= 'HAD DIFFCLTY THNKNG CLEARLY PST YR DUE T'
   NTKDRG1A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-1'
   NTKDRG2A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-2'
   NTKDRG3A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-3'
   NTKDRG4A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-4'
   NTKDRG5A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-5'
   NTKDRG6A= 'DRUG CAUSING DIFFICULTY THINKING CLEAR-6'
   DRMNYPRB= 'HAD SERIOUS MONEY PROBLEMS'
   MNYDRG1A= '1ST DRUG CAUSING SERIOUS MONEY PROBLEMS'
   MNYDRG2A= '2ND DRUG CAUSING SERIOUS MONEY PROBLEMS'
   MNYDRG3A= '3RD DRUG CAUSING SERIOUS MONEY PROBLEMS'
   MNYDRG4A= '4TH DRUG CAUSING SERIOUS MONEY PROBLEMS'
   MNYDRG5A= '5TH DRUG CAUSING SERIOUS MONEY PROBLEMS'
   MNYDRG6A= '6TH DRUG CAUSING SERIOUS MONEY PROBLEMS'
   DRUPSET = 'FELT IRRITABLE/UPSET PAST YEAR DUE TO DR'
   UPSDRG1A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-1ST'
   UPSDRG2A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-2ND'
   UPSDRG3A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-3RD'
   UPSDRG4A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-4TH'
   UPSDRG5A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-5TH'
   UPSDRG6A= 'DRUG CAUSING FEELING IRRITABLE/UPSET-6TH'
   DRLSWORK= 'GOT LESS WRK DONE @ SCH/JOB PST YR DUE T'
   LSWDRG1A= 'DRUG CAUSING LESS WORK GETTING DONE-1ST'
   LSWDRG2A= 'DRUG CAUSING LESS WORK GETTING DONE-2ND'
   LSWDRG3A= 'DRUG CAUSING LESS WORK GETTING DONE-3RD'
   LSWDRG4A= 'DRUG CAUSING LESS WORK GETTING DONE-4TH'
   LSWDRG5A= 'DRUG CAUSING LESS WORK GETTING DONE-5TH'
   LSWDRG6A= 'DRUG CAUSING LESS WORK GETTING DONE-6TH'
   DRSUSPIC= 'FELT DISTRUSTFUL/SUSPICIOUS PST YR DUE T'
   SSPDRG1A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-1S'
   SSPDRG2A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-2N'
   SSPDRG3A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-3R'
   SSPDRG4A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-4T'
   SSPDRG5A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-5T'
   SSPDRG6A= 'DRUG CAUSING FEELING SUSPIC./DISTRUST-6T'
   DRTRBLAW= 'HAD TROUBLE WITH THE POLICE'
   LAWDRG1A= '1ST DRUG CAUSING TROUBLE WITH THE POLICE'
   LAWDRG2A= '2ND DRUG CAUSING TROUBLE WITH THE POLICE'
   LAWDRG3A= '3RD DRUG CAUSING TROUBLE WITH THE POLICE'
   LAWDRG4A= '4TH DRUG CAUSING TROUBLE WITH THE POLICE'
   LAWDRG5A= '5TH DRUG CAUSING TROUBLE WITH THE POLICE'
   LAWDRG6A= '6TH DRUG CAUSING TROUBLE WITH THE POLICE'
   DRNOTEAT= 'SKIPPED FOUR OR MORE REGULAR MEALS IN A'
   NETDRG1A= '1ST DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   NETDRG2A= '2ND DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   NETDRG3A= '3RD DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   NETDRG4A= '4TH DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   NETDRG5A= '5TH DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   NETDRG6A= '6TH DRUG CAUSED SKIPPING 4+ REGULAR MEAL'
   DRCOPE  = 'PROBLEMS HARDER TO HANDLE PAST YR DUE TO'
   CPEDRG1A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-1S'
   CPEDRG2A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-2N'
   CPEDRG3A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-3R'
   CPEDRG4A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-4T'
   CPEDRG5A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-5T'
   CPEDRG6A= 'DRUG MAKING PROBLEMS HARDER TO HANDLE-6T'
   DREMGMED= 'HAD TO GET EMERG MED HELP PST YR DUE TO'
   EMDRG1A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-1S'
   EMDRG2A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-2N'
   EMDRG3A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-3R'
   EMDRG4A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-4T'
   EMDRG5A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-5T'
   EMDRG6A = 'DRUG CAUSING NEED FOR EMER. MED. HELP-6T'
   AS14READ= 'ANSWER SHEET #14 - READING PREFERENCE'
   HLPQTCIG= 'EVER BEEN TO CLINIC, DOCTOR, ETC. TO QUI'
   HLPALCHO= 'EVER BEEN TO CLINIC, DOCTOR, ETC. TO QUI'
   HLPDRUSE= 'EVER SOUGHT HELP FOR NON-CIG/ALC DRUG US'
   TRTER   = 'EVER REC''D TREATMT FOR DRUG USE IN EMER'
   TRTHOSP = 'EVER REC''D TREATMT FOR DRUG USE IN HOSP'
   TRTPDOC = 'EVER REC''D TREATMT FOR DRUG USE IN DR.'
   TRTREH  = 'EVER REC''D TREATMT FOR DRUG USE IN REHA'
   TRTMHF  = 'EVER REC''D TREATMT FOR DRUGS IN MENTAL'
   TRTSHELP= 'EVER REC''D TREATMT FOR DRUGS IN SELF-HE'
   TRTOTHER= 'OTHER TREATMENT RESPONSE SPECIFIED'
   TRTNONE = 'NEVER RECEIVED TREATMENT FOR NON CIG/ALC'
   TRTNEWA = 'OTHER TREATMENT SPECIFIED - 1ST MENTION'
   TRTNEWB = 'OTHER TREATMENT SPECIFIED - 2ND MENTION'
   TRTCALL = 'EVER CALLED DRUG TRMT PROGRAM FOR SELF O'
   TRTCALLO= 'EVER CALLED DRUG TRMT PROGRAM FOR SELF'
   TRTDRGYR= 'RECEIVED TREATMT FOR NON-ALC/CIG DRUGS P'
   TRTPRBYR= 'REC''D TRMT FOR ANY DRUG-RELATED ILLNESS'
   RSKPKCIG= 'RISK IF SMOKE 1 OR MORE PACKS CIGARETTES'
   RSKMJOCC= 'RISK IF SMOKE MARIJUANA OCCASIONALLY'
   RSKMJREG= 'RISK IF SMOKE MARIJUANA REGULARLY'
   RKTRYPCP= 'RISK IF TRY PCP ONCE OR TWICE'
   RKPCPREG= 'RISK IF USE PCP REGULARLY'
   RKTRYHER= 'RISK IF TRY HEROIN ONCE OR TWICE'
   RKHERREG= 'RISK IF USE HEROIN REGULARLY'
   RKTRYCOC= 'RISK IF TRY COCAINE ONCE OR TWICE'
   RKCOCOCC= 'RISK IF USE COCAINE OCCASIONALLY'
   RKCOCREG= 'RISK IF USE COCAINE REGULARLY'
   RK2DRINK= 'RISK IF TAKE 1 OR 2 DRINKS NEARLY EVERY'
   RK5DRINK= 'RISK IF TAKE 4 OR 5 DRINKS NEARLY EVERY'
   RSKBINGE= 'RISK IF HAVE 5 OR MORE DRINKS ONCE OR TW'
   SEX     = 'SEX OF RESPONDENT'
   BIRMON  = 'BIRTH MONTH'
   BIRYEAR = 'BIRTH YEAR'
   MARITAL = 'MARITAL STATUS'
   NOMARR  = '# TIMES MARRIED'
   WORKSTAT= 'PRESENT WORK SITUATION'
   PAYYR   = 'YEAR (19__) LAST WORKED FOR PAY'
   PAYMO   = 'MONTH LAST WORKED FOR PAY'
   ROCCUP1 = 'KIND OF WORK OF RESPONDENT'
   BUSINES1= 'BUSINESS OR INDUSTRY OF RESPONDENT'
   NO5JOB  = '# OF JOBS LAST 5 YEARS'
   CWE     = 'CHIEF WAGE EARNER IN HOUSEHOLD (RELATION'
   FULLPART= 'WORK STATUS OF CHIEF WAGE EARNER'
   CWEOCC1 = 'KIND OF WORK OF CHIEF WAGE EARNER'
   CWEBUS1 = 'BUSINESS OR INDUSTRY OF CHIEF WAGE EARNE'
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL'
   STUDENT = 'STUDENT STATUS NOW'
   SCHDAYS = '# OF DAYS MISSED SCHOOL DUE TO ILL/INJUR'
   SKIPPED = '# DAYS SKIPPED SCHOOL LAST MONTH'
   WORKDAYS= '# DAYS MISSED WORK DUE TO ILL/INJURY LAS'
   WORKBLAH= '# DAYS SKIPPED WORK LAST 30 DAYS'
   MILES   = '# MILES RESPONDENT DRIVES IN A TYPICAL W'
   ACCID   = 'HAD MOTOR VEHICLE ACCIDENT IN PAST 12 MO'
   NOCHILD = '# OF BIOLOGICAL CHILDREN'
   CHAGE1  = 'NUMBER OF CHILDREN AGES 0 TO 2'
   CHAGE2  = 'NUMBER OF CHILDREN AGES 3 TO 5'
   CHAGE3  = 'NUMBER OF CHILDREN AGES 6 TO 8'
   CHAGE4  = 'NUMBER OF CHILDREN AGES 9 TO 11'
   CHAGE5  = 'NUMBER OF CHILDREN AGES 12 TO 14'
   CHAGE6  = 'NUMBER OF CHILDREN AGES 15 TO 17'
   CHAGE7  = 'NUMBER OF CHILDREN AGES 18 TO 24'
   CHAGE8  = 'NUMBER OF CHILDREN AGES 25 TO 34'
   CHAGE9  = 'NUMBER OF CHILDREN AGES 35+'
   CHAGE10 = 'NUMBER OF CHILDREN W/AGES UNKNOWN OR UNS'
   TOTPEOP = '# OF RESIDENTS IN HOUSEHOLD'
   MOTHER  = 'MOTHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   FATHER  = 'FATHER OF RESPONDENT MEMBER OF HOUSEHOLD'
   SPOUSE  = 'SPOUSE/LIVE-IN PARTNER OF RESP MEMBER OF'
   INLAW   = '# PARENT(S)-IN-LAW OF RESP LIVING IN HOU'
   OWNCHILD= '# BIOLOGICAL CHILDREN OF RESP LIVING IN'
   STEPCHLD= '# ADOPTED/STEPCHILDREN OF RESP LIVING IN'
   BROSIS  = '# BROTHERS/SISTERS OF RESP LIVING IN HOU'
   OTHREL  = '# OTHER RELATIVES OF RESP LIVING IN HOUS'
   FRIENDS = '# FRIENDS/ROOMMATES OF RESP LIVING IN HO'
   OTHERNON= '# OTHER PEOPLE UNRELATD TO RESP LIVING I'
   SERVICE = 'EVER SERVED IN ARMED FORCES'
   MILSTAT = 'CURRENT MILITARY STATUS'
   MILYR1A = '1ST PERIOD OF MILITARY SERVICE-BEGINNING'
   MILYR2A = '1ST PERIOD OF MILITARY SERVICE-ENDING YE'
   MILYR3A = '2ND PERIOD OF MILITARY SERVICE-BEGINNING'
   MILYR4A = '2ND PERIOD OF MILITARY SERVICE-ENDING YE'
   MILYR5A = '3RD PERIOD OF MILITARY SERVICE-BEGINNING'
   MILYR6A = '3RD PERIOD OF MILITARY SERVICE-ENDING YE'
   YRENTS  = 'WHEN DID YOU LAST ENTER THE SERVICE (YEA'
   VIETNAM = 'DID YOU SERVE IN VIETNAM?'
   DORM    = '# OF FORMER RESIDENTS NOW LIVING AT COLL'
   MILBASE = '# OF FORMER RESIDENTS NOW LIVING ON MILI'
   HOSP    = '# OF FORMR RESDNTS NOW LVNG IN JAIL,HOSP'
   TELNO   = '# OF PHONE NUMBERS IN HOUSEHOLD'
   MOVES   = '# OF TIMES MOVED PAST 5 YEARS'
   INCOME  = 'PERSONAL EARNINGS FROM EMPLOYMENT FOR PA'
   INTDATE = 'EDITED INTERVIEW DATE'
   EIIDATE = 'EDIT INDICATOR FOR INTERVIEW DATE'
   INTMONTH= 'INTERVIEW MONTH'
   PARQ    = 'PARENT TOOK QUESTIONNAIRE FROM INTERVIEW'
   UNDINT  = 'ESTIMATE RESPONDENT''S UNDERSTANDING OF'
   COOPINT = 'COOPERATION OF RESPONDENT'
   PRIVACY = 'SCALE FOR PRIVACY DURING INTERVIEW'
   PPRES   = 'PARENT(S) PRESENT OR LISTENING TO INTERV'
   SPRES   = 'SPOUSE PRESENT OR LISTENING TO INTERVIEW'
   PARPRES = 'LIVE-IN PARTNR/DATE PRSNT OR LISTENNG TO'
   OARPRES = 'OTHER ADULT RELATIVE(S) PRES/LSTENING TO'
   OAPRES  = 'OTHER ADULT(S) PRESENT OR LISTENING TO I'
   CPRES   = 'CHILD(REN) UNDER 15 PRESENT/LISTENING TO'
   OPRES   = 'OTHER PERSON(S) PRESENT/LISTENING (NOT S'
   POPDEN  = 'POPULATION DENSITY (BASED ON 1980 CENSUS'
   REGION  = 'CENSUS REGION'
   DIVISION= 'CENSUS DIVISION CODE'
   EIBDATE = 'EDIT INDICATOR FOR BIRTHDATE'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IIAGE   = 'IMPUTATION INDICATOR FOR AGE'
   IRSEX   = 'SEX - IMPUTATION REVISED'
   IISEX   = 'SEX - IMPUTATION INDICATOR'
   IRRACE  = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACE  = 'IMPUTATION INDICATOR FOR RACE'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IMPUTATION INDICATOR FOR HISPANIC ORIGIN'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC-ORIGIN'
   IRHOGRP2= 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP2= 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRMARIT = 'MARITAL STATUS - IMPUTATION REVISED'
   IIMARIT = 'MARITAL STATUS - IMPUTATION INDICATOR'
   IREDUC  = 'EDUCATION - IMPUTATION REVISED'
   IIEDUC  = 'EDUCATION - IMPUTATION INDICATOR'
   IRWORKST= 'WORK STATUS - IMPUTATION REVISED'
   IIWORKST= 'WORK STATUS - IMPUTATION INDICATOR'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRSEDRC = 'SEDATIVES RECENCY - IMPUTATION REVISED'
   IISEDRC = 'SEDATIVES RECENCY - IMPUTATION INDICATOR'
   IRTRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION REVIS'
   IITRNRC = 'TRANQUILIZERS RECENCY - IMPUTATION INDIC'
   IRSTMRC = 'STIMULANTS RECENCY - IMPUTATION REVISED'
   IISTMRC = 'STIMULANTS RECENCY - IMPUTATION INDICATO'
   IRANLRC = 'ANALGESICS RECENCY - IMPUTATION REVISED'
   IIANLRC = 'ANALGESICS RECENCY - IMPUTATION INDICATO'
   IRCIGRC = 'CIGARETTES RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTES RECENCY - IMPUTATION INDICATO'
   IRINHRC = 'INHALANTS RECENCY - IMPUTATION REVISED'
   IIINHRC = 'INHALANTS RECENCY - IMPUTATION INDICATOR'
   IRHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION REVIS'
   IIHALRC = 'HALLUCINOGENS RECENCY - IMPUTATION INDIC'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   IRALCFQ = 'ALCOHOL FREQUENCY PAST  YEAR - IMPUTATIO'
   IIALCFQ = 'ALCOHOL FREQUENCY - IMPUTATION INDICATOR'
   IRMJFQ  = 'MARIJUANA FREQUENCY PAST YEAR - IMPUTATI'
   IIMJFQ  = 'MARIJUANA FREQUENCY - IMPUTATION INDICAT'
   IRCOCFQ = 'COCAINE FREQUENCY PAST YEAR - IMPUTATION'
   IICOCFQ = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   CATAGE  = 'AGE CATEGORY'
   CATAG2  = 'AGE CATEGORY RECODE (3 LEVELS)'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   EDUCCAT2= 'EDUCATION RECODE'
   EMPSTAT2= 'EMPLOYMENT STATUS RECODE'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   INHFLAG = 'INHALANTS - EVER USED'
   INHYR   = 'INHALANTS - PAST YEAR USE'
   INHMON  = 'INHALANTS - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYR   = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAG = 'ANY ILLICIT DRUG - EVER USED'
   SUMYR   = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMON  = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAG = 'MARIJUANA ONLY - EVER USED'
   MJOYR2  = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2 = 'MARIJUANA ONLY - PAST MONTH USE'
   IEMFLAG = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - EVER'
   IEMYR   = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - PAST'
   IEMMON  = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - PST'
   ALCDLYF = 'ALCOHOL DAILY/ALMOST FLAG'
   ALCWKF  = 'ALCOHOL - WEEKLY OR MORE FREQUENT USE PA'
   ALCMONF = 'ALCOHOL - MONTHLY OR MORE FREQUENT USE P'
   ALCOCCF = 'ALCOHOL OCCASIONAL FLAG'
   ALCYRF  = 'ALCOHOL - ANY USE PAST YEAR'
   MRJDLYF = 'MARIJUANA DAILY/ALMOST FLAG'
   MRJWKF  = 'MARIJUANA - WEEKLY OR MORE FREQUENT USE'
   MRJMONF = 'MARIJUANA - MONTHLY OR MORE FREQUENT USE'
   MRJOCCF = 'MARIJUANA OCCASIONAL FLAG'
   MRJYRF  = 'MARIJUANA - ANY USE PAST YEAR'
   COCDLYF = 'COCAINE DAILY/ALMOST FLAG'
   COCWKF  = 'COCAINE - WEEKLY OR MORE FREQUENT USE PA'
   COCMONF = 'COCAINE - MONTHLY OR MORE FREQUENT USE P'
   COCOCCF = 'COCAINE OCCASIONAL FLAG'
   COCYRF  = 'COCAINE - ANY USE PAST YEAR'
   ANALWT  = 'REVISED 1985 ANALYSIS WEIGHT'
   VEREP   = 'REPLICATE WITHIN ANALYSIS STRATUM'
   VESTR   = 'STRATUM TO BE USED IN ANALYSIS'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGTRY >= 91) THEN CIGTRY = .;
   IF (CIG5PK >= 91) THEN CIG5PK = .;
   IF (CIGREC >= 91) THEN CIGREC = .;
   IF (AVCIG >= 91) THEN AVCIG = .;
   IF (CIGINT >= 91) THEN CIGINT = .;
   IF (CIGTIME >= 91) THEN CIGTIME = .;
   IF (CIGAGE >= 91) THEN CIGAGE = .;
   IF (CIGYRS >= 91) THEN CIGYRS = .;
   IF (PACKS >= 91) THEN PACKS = .;
   IF (OTHTOB >= 91) THEN OTHTOB = .;
   IF (ADDALC >= 91) THEN ADDALC = .;
   IF (ADDMJ >= 91) THEN ADDMJ = .;
   IF (ADDSED >= 91) THEN ADDSED = .;
   IF (ADDTRAN >= 91) THEN ADDTRAN = .;
   IF (ADDAMP >= 91) THEN ADDAMP = .;
   IF (ADDCOC >= 91) THEN ADDCOC = .;
   IF (ADDLSD >= 91) THEN ADDLSD = .;
   IF (ADDHER >= 91) THEN ADDHER = .;
   IF (ADDCIG >= 91) THEN ADDCIG = .;
   IF (ADDNONE >= 91) THEN ADDNONE = .;
   IF (ADDALL >= 91) THEN ADDALL = .;
   IF (ALCTRY >= 91) THEN ALCTRY = .;
   IF (ALCREC >= 91) THEN ALCREC = .;
   IF (ALCPREF >= 91) THEN ALCPREF = .;
   IF (ALCDAYS >= 91) THEN ALCDAYS = .;
   IF (NODR30A >= 91) THEN NODR30A = .;
   IF (MODR30A >= 91) THEN MODR30A = .;
   IF (MODR30DY >= 91) THEN MODR30DY = .;
   IF (DR5DAY >= 91) THEN DR5DAY = .;
   IF (ALCAGE >= 91) THEN ALCAGE = .;
   IF (ALCPAT >= 91) THEN ALCPAT = .;
   IF (DRUNKYR >= 9) THEN DRUNKYR = .;
   IF (ALCSED >= 91) THEN ALCSED = .;
   IF (ALCTRAN >= 91) THEN ALCTRAN = .;
   IF (ALCSTM >= 91) THEN ALCSTM = .;
   IF (ALCANAL >= 91) THEN ALCANAL = .;
   IF (ALCMJ >= 91) THEN ALCMJ = .;
   IF (ALCINH >= 91) THEN ALCINH = .;
   IF (ALCCOC >= 91) THEN ALCCOC = .;
   IF (ALCHAL >= 91) THEN ALCHAL = .;
   IF (ALCOPT >= 91) THEN ALCOPT = .;
   IF (ALCNONE >= 91) THEN ALCNONE = .;
   IF (BUTISOL >= 91) THEN BUTISOL = .;
   IF (BUTICAPS >= 91) THEN BUTICAPS = .;
   IF (AMYTAL >= 91) THEN AMYTAL = .;
   IF (ESKABARB >= 91) THEN ESKABARB = .;
   IF (LUMINAL >= 91) THEN LUMINAL = .;
   IF (MEBARAL >= 91) THEN MEBARAL = .;
   IF (AMOBARB >= 91) THEN AMOBARB = .;
   IF (PHENOBAR >= 91) THEN PHENOBAR = .;
   IF (ALURATE >= 91) THEN ALURATE = .;
   IF (PLACIDYL >= 91) THEN PLACIDYL = .;
   IF (DORIDEN >= 91) THEN DORIDEN = .;
   IF (NOLUDAR >= 91) THEN NOLUDAR = .;
   IF (SOPOR >= 91) THEN SOPOR = .;
   IF (QUAALUDE >= 91) THEN QUAALUDE = .;
   IF (PAREST >= 91) THEN PAREST = .;
   IF (NOCTEC >= 91) THEN NOCTEC = .;
   IF (METHAQ >= 91) THEN METHAQ = .;
   IF (CHHYD >= 91) THEN CHHYD = .;
   IF (NEMBUTAL >= 91) THEN NEMBUTAL = .;
   IF (CARBTAL >= 91) THEN CARBTAL = .;
   IF (SECONAL >= 91) THEN SECONAL = .;
   IF (TUINAL >= 91) THEN TUINAL = .;
   IF (PENTOB >= 91) THEN PENTOB = .;
   IF (SECOB >= 91) THEN SECOB = .;
   IF (DALMANE >= 91) THEN DALMANE = .;
   IF (SEDDKNAM >= 91) THEN SEDDKNAM = .;
   IF (SEDOTH >= 91) THEN SEDOTH = .;
   IF (SEDNEWA >= 991) THEN SEDNEWA = .;
   IF (SEDNEWB >= 991) THEN SEDNEWB = .;
   IF (SEDNEWC >= 991) THEN SEDNEWC = .;
   IF (SEDAGE >= 91) THEN SEDAGE = .;
   IF (SEDTOT >= 91) THEN SEDTOT = .;
   IF (SEDREC >= 91) THEN SEDREC = .;
   IF (SEDALC >= 91) THEN SEDALC = .;
   IF (SEDTR >= 91) THEN SEDTR = .;
   IF (SEDST >= 91) THEN SEDST = .;
   IF (SEDAN >= 91) THEN SEDAN = .;
   IF (SEDMJ >= 91) THEN SEDMJ = .;
   IF (SEDINH >= 91) THEN SEDINH = .;
   IF (SEDCOC >= 91) THEN SEDCOC = .;
   IF (SEDHAL >= 91) THEN SEDHAL = .;
   IF (SEDOPT >= 91) THEN SEDOPT = .;
   IF (SEDNONE >= 91) THEN SEDNONE = .;
   IF (AS3READ >= 91) THEN AS3READ = .;
   IF (VALIUM >= 91) THEN VALIUM = .;
   IF (LIBRIUM >= 91) THEN LIBRIUM = .;
   IF (LIBTAB >= 91) THEN LIBTAB = .;
   IF (SKLY >= 91) THEN SKLY = .;
   IF (SERAX >= 91) THEN SERAX = .;
   IF (TRANXENE >= 91) THEN TRANXENE = .;
   IF (ATIVAN >= 91) THEN ATIVAN = .;
   IF (VERSTRAN >= 91) THEN VERSTRAN = .;
   IF (MEPRSPAN >= 91) THEN MEPRSPAN = .;
   IF (MILTOWN >= 91) THEN MILTOWN = .;
   IF (EQUANIL >= 91) THEN EQUANIL = .;
   IF (MEPROB >= 91) THEN MEPROB = .;
   IF (VISTAR >= 91) THEN VISTAR = .;
   IF (ATARAX >= 91) THEN ATARAX = .;
   IF (BENADRYL >= 91) THEN BENADRYL = .;
   IF (XANAX >= 91) THEN XANAX = .;
   IF (TRDKNAM >= 91) THEN TRDKNAM = .;
   IF (TROTH >= 91) THEN TROTH = .;
   IF (TRNEWA >= 991) THEN TRNEWA = .;
   IF (TRNEWB >= 991) THEN TRNEWB = .;
   IF (TRNEWC >= 991) THEN TRNEWC = .;
   IF (TRANAGE >= 91) THEN TRANAGE = .;
   IF (TRANTOT >= 91) THEN TRANTOT = .;
   IF (TRANREC >= 91) THEN TRANREC = .;
   IF (TRALC >= 91) THEN TRALC = .;
   IF (TRSED >= 91) THEN TRSED = .;
   IF (TRSTM >= 91) THEN TRSTM = .;
   IF (TRANAL >= 91) THEN TRANAL = .;
   IF (TRMJ >= 91) THEN TRMJ = .;
   IF (TRINH >= 91) THEN TRINH = .;
   IF (TRCOC >= 91) THEN TRCOC = .;
   IF (TRHAL >= 91) THEN TRHAL = .;
   IF (TROPT >= 91) THEN TROPT = .;
   IF (TRNONE >= 91) THEN TRNONE = .;
   IF (AS4READ >= 91) THEN AS4READ = .;
   IF (DEXED >= 91) THEN DEXED = .;
   IF (DEXAMYL >= 91) THEN DEXAMYL = .;
   IF (ESKAT >= 91) THEN ESKAT = .;
   IF (BENZ >= 91) THEN BENZ = .;
   IF (BIPHET >= 91) THEN BIPHET = .;
   IF (DESOXYN >= 91) THEN DESOXYN = .;
   IF (DETAMP >= 91) THEN DETAMP = .;
   IF (METHI >= 91) THEN METHI = .;
   IF (OBLA >= 91) THEN OBLA = .;
   IF (TENUATE >= 91) THEN TENUATE = .;
   IF (TEPANIL >= 91) THEN TEPANIL = .;
   IF (DIDREX >= 91) THEN DIDREX = .;
   IF (PLEGINE >= 91) THEN PLEGINE = .;
   IF (PRELUDIN >= 91) THEN PRELUDIN = .;
   IF (PRESATE >= 91) THEN PRESATE = .;
   IF (IONAMIN >= 91) THEN IONAMIN = .;
   IF (PONDIMIN >= 91) THEN PONDIMIN = .;
   IF (VORANIL >= 91) THEN VORANIL = .;
   IF (SANOREX >= 91) THEN SANOREX = .;
   IF (RITALIN >= 91) THEN RITALIN = .;
   IF (CYLERT >= 91) THEN CYLERT = .;
   IF (STMDKNAM >= 91) THEN STMDKNAM = .;
   IF (STIMOR >= 91) THEN STIMOR = .;
   IF (STIMNEWA >= 991) THEN STIMNEWA = .;
   IF (STIMNEWB >= 991) THEN STIMNEWB = .;
   IF (STIMNEWC >= 991) THEN STIMNEWC = .;
   IF (STIMAGE >= 91) THEN STIMAGE = .;
   IF (STIMTOT >= 91) THEN STIMTOT = .;
   IF (STIMREC >= 91) THEN STIMREC = .;
   IF (STALC >= 91) THEN STALC = .;
   IF (STSED >= 91) THEN STSED = .;
   IF (STTRAN >= 91) THEN STTRAN = .;
   IF (STANAL >= 91) THEN STANAL = .;
   IF (STMJ >= 91) THEN STMJ = .;
   IF (STINH >= 91) THEN STINH = .;
   IF (STCOC >= 91) THEN STCOC = .;
   IF (STHAL >= 91) THEN STHAL = .;
   IF (STOPT >= 91) THEN STOPT = .;
   IF (STNONE >= 91) THEN STNONE = .;
   IF (AS5READ >= 91) THEN AS5READ = .;
   IF (ANALNONE >= 91) THEN ANALNONE = .;
   IF (DARVON >= 91) THEN DARVON = .;
   IF (DOLENE >= 91) THEN DOLENE = .;
   IF (SK65A >= 91) THEN SK65A = .;
   IF (PROPOXY >= 91) THEN PROPOXY = .;
   IF (LERITINE >= 91) THEN LERITINE = .;
   IF (LEVODRO >= 91) THEN LEVODRO = .;
   IF (PERCODAN >= 91) THEN PERCODAN = .;
   IF (DEMEROL >= 91) THEN DEMEROL = .;
   IF (DILAUD >= 91) THEN DILAUD = .;
   IF (TYLCOD >= 91) THEN TYLCOD = .;
   IF (CODEINE >= 91) THEN CODEINE = .;
   IF (DOLOP >= 91) THEN DOLOP = .;
   IF (WESTOD >= 91) THEN WESTOD = .;
   IF (METHDON >= 91) THEN METHDON = .;
   IF (TALWIN >= 91) THEN TALWIN = .;
   IF (ANLDKNAM >= 91) THEN ANLDKNAM = .;
   IF (ANALOTH >= 91) THEN ANALOTH = .;
   IF (ANALNEWA >= 991) THEN ANALNEWA = .;
   IF (ANALNEWB >= 991) THEN ANALNEWB = .;
   IF (ANALNEWC >= 991) THEN ANALNEWC = .;
   IF (ANALAGE >= 91) THEN ANALAGE = .;
   IF (ANALTOT >= 91) THEN ANALTOT = .;
   IF (ANALREC >= 91) THEN ANALREC = .;
   IF (ANLALC >= 91) THEN ANLALC = .;
   IF (ANLSED >= 91) THEN ANLSED = .;
   IF (ANLTRAN >= 91) THEN ANLTRAN = .;
   IF (ANLSTM >= 91) THEN ANLSTM = .;
   IF (ANLMJ >= 91) THEN ANLMJ = .;
   IF (ANLINH >= 91) THEN ANLINH = .;
   IF (ANLCOC >= 91) THEN ANLCOC = .;
   IF (ANLHAL >= 91) THEN ANLHAL = .;
   IF (ANLOPT >= 91) THEN ANLOPT = .;
   IF (ANLNONE >= 91) THEN ANLNONE = .;
   IF (MJOPP >= 91) THEN MJOPP = .;
   IF (MJAGE >= 91) THEN MJAGE = .;
   IF (MJTOT >= 91) THEN MJTOT = .;
   IF (MJREC >= 91) THEN MJREC = .;
   IF (MJDAY30A >= 91) THEN MJDAY30A = .;
   IF (MJAV30A >= 91) THEN MJAV30A = .;
   IF (MJAMT30A >= 91) THEN MJAMT30A = .;
   IF (MJDOL >= 9991) THEN MJDOL = .;
   IF (MJALC30A >= 6) THEN MJALC30A = .;
   IF (MJYRFREQ >= 91) THEN MJYRFREQ = .;
   IF (MJALC >= 91) THEN MJALC = .;
   IF (MJSED >= 91) THEN MJSED = .;
   IF (MJTRAN >= 91) THEN MJTRAN = .;
   IF (MJSTM >= 91) THEN MJSTM = .;
   IF (MJANAL >= 91) THEN MJANAL = .;
   IF (MJINH >= 91) THEN MJINH = .;
   IF (MJCOC >= 91) THEN MJCOC = .;
   IF (MJHAL >= 91) THEN MJHAL = .;
   IF (MJOPT >= 91) THEN MJOPT = .;
   IF (MJNONE >= 91) THEN MJNONE = .;
   IF (AS7READ >= 91) THEN AS7READ = .;
   IF (INHNONE >= 91) THEN INHNONE = .;
   IF (GAS >= 91) THEN GAS = .;
   IF (SPPAINT >= 91) THEN SPPAINT = .;
   IF (AEROS >= 91) THEN AEROS = .;
   IF (GLUE >= 91) THEN GLUE = .;
   IF (SOLVENT >= 91) THEN SOLVENT = .;
   IF (AMYLNIT >= 91) THEN AMYLNIT = .;
   IF (ETHER >= 91) THEN ETHER = .;
   IF (NITOXID >= 91) THEN NITOXID = .;
   IF (CLEFLU >= 91) THEN CLEFLU = .;
   IF (OTHINHL >= 91) THEN OTHINHL = .;
   IF (INHNEWA >= 991) THEN INHNEWA = .;
   IF (GAS30A >= 91) THEN GAS30A = .;
   IF (SPPAN30A >= 91) THEN SPPAN30A = .;
   IF (AEROS30A >= 91) THEN AEROS30A = .;
   IF (GLUE30A >= 91) THEN GLUE30A = .;
   IF (SOLVN30A >= 91) THEN SOLVN30A = .;
   IF (AMLNT30A >= 91) THEN AMLNT30A = .;
   IF (ETHER30A >= 91) THEN ETHER30A = .;
   IF (NOX30A >= 91) THEN NOX30A = .;
   IF (CLFL30A >= 91) THEN CLFL30A = .;
   IF (INHOT30A >= 91) THEN INHOT30A = .;
   IF (INH30NO >= 91) THEN INH30NO = .;
   IF (INHTOT >= 91) THEN INHTOT = .;
   IF (INHREC >= 91) THEN INHREC = .;
   IF (INHDY30A >= 91) THEN INHDY30A = .;
   IF (INHEFF >= 91) THEN INHEFF = .;
   IF (INHPO >= 91) THEN INHPO = .;
   IF (INHQNC >= 91) THEN INHQNC = .;
   IF (INHANSY >= 91) THEN INHANSY = .;
   IF (AS8READ >= 91) THEN AS8READ = .;
   IF (COCOPP >= 91) THEN COCOPP = .;
   IF (COCAGE >= 91) THEN COCAGE = .;
   IF (COCTOT >= 91) THEN COCTOT = .;
   IF (COCREC >= 91) THEN COCREC = .;
   IF (COCUS30A >= 91) THEN COCUS30A = .;
   IF (COCAM30A >= 91) THEN COCAM30A = .;
   IF (COCBUCK >= 9991) THEN COCBUCK = .;
   IF (COC30ALC >= 6) THEN COC30ALC = .;
   IF (COCYRFRQ >= 91) THEN COCYRFRQ = .;
   IF (COCALC >= 91) THEN COCALC = .;
   IF (COCSED >= 91) THEN COCSED = .;
   IF (COCTRAN >= 91) THEN COCTRAN = .;
   IF (COCSTM >= 91) THEN COCSTM = .;
   IF (COCANAL >= 91) THEN COCANAL = .;
   IF (COCMJ >= 91) THEN COCMJ = .;
   IF (COCINH >= 91) THEN COCINH = .;
   IF (COCHAL >= 91) THEN COCHAL = .;
   IF (COCOPT >= 91) THEN COCOPT = .;
   IF (COCNONE >= 91) THEN COCNONE = .;
   IF (COCSNIFX >= 91) THEN COCSNIFX = .;
   IF (COCSWALX >= 91) THEN COCSWALX = .;
   IF (COCIVX >= 91) THEN COCIVX = .;
   IF (FREEBASX >= 91) THEN FREEBASX = .;
   IF (COCOTHX >= 91) THEN COCOTHX = .;
   IF (AS9READ >= 91) THEN AS9READ = .;
   IF (HALLQCL >= 91) THEN HALLQCL = .;
   IF (HALLOPP >= 91) THEN HALLOPP = .;
   IF (HALLAGE >= 91) THEN HALLAGE = .;
   IF (HALLTOT >= 91) THEN HALLTOT = .;
   IF (HALLREC >= 91) THEN HALLREC = .;
   IF (HAL30USE >= 91) THEN HAL30USE = .;
   IF (LSD >= 91) THEN LSD = .;
   IF (PEYOTE >= 91) THEN PEYOTE = .;
   IF (MESC >= 91) THEN MESC = .;
   IF (PSILCY >= 91) THEN PSILCY = .;
   IF (PCP >= 91) THEN PCP = .;
   IF (HALLOTH >= 91) THEN HALLOTH = .;
   IF (HALNEWA >= 991) THEN HALNEWA = .;
   IF (HALNEWB >= 991) THEN HALNEWB = .;
   IF (PCPREC >= 91) THEN PCPREC = .;
   IF (PCPFLASH >= 91) THEN PCPFLASH = .;
   IF (PCPSENSE >= 91) THEN PCPSENSE = .;
   IF (PCPFEELV >= 91) THEN PCPFEELV = .;
   IF (PCPACTV >= 91) THEN PCPACTV = .;
   IF (PCPOTH >= 91) THEN PCPOTH = .;
   IF (PCPNORCT >= 91) THEN PCPNORCT = .;
   IF (PCPNEWA >= 91) THEN PCPNEWA = .;
   IF (PCPNEWB >= 91) THEN PCPNEWB = .;
   IF (AS10READ >= 91) THEN AS10READ = .;
   IF (HEROPP >= 91) THEN HEROPP = .;
   IF (HERAGE >= 91) THEN HERAGE = .;
   IF (HERTOT >= 91) THEN HERTOT = .;
   IF (HERREC >= 91) THEN HERREC = .;
   IF (HER30USE >= 91) THEN HER30USE = .;
   IF (HERNEEDL >= 91) THEN HERNEEDL = .;
   IF (HIGHBP >= 91) THEN HIGHBP = .;
   IF (BPMED >= 91) THEN BPMED = .;
   IF (WALKPAIN >= 91) THEN WALKPAIN = .;
   IF (TIMEPAIN >= 91) THEN TIMEPAIN = .;
   IF (UPSHOR >= 91) THEN UPSHOR = .;
   IF (ASTHMA >= 91) THEN ASTHMA = .;
   IF (TRPSYCH >= 91) THEN TRPSYCH = .;
   IF (HEART >= 91) THEN HEART = .;
   IF (FLU >= 91) THEN FLU = .;
   IF (ALLERG >= 91) THEN ALLERG = .;
   IF (HOSPYR >= 91) THEN HOSPYR = .;
   IF (SOREYR >= 91) THEN SOREYR = .;
   IF (RUNNYYR >= 91) THEN RUNNYYR = .;
   IF (COUGHYR >= 91) THEN COUGHYR = .;
   IF (PHLEGMYR >= 91) THEN PHLEGMYR = .;
   IF (HEALTHYR >= 91) THEN HEALTHYR = .;
   IF (FELTGOOD >= 91) THEN FELTGOOD = .;
   IF (FELTMIND >= 91) THEN FELTMIND = .;
   IF (FELTDEP >= 91) THEN FELTDEP = .;
   IF (FELTEFF >= 91) THEN FELTEFF = .;
   IF (FELTHOPE >= 91) THEN FELTHOPE = .;
   IF (FELTSLEP >= 91) THEN FELTSLEP = .;
   IF (FELTHAP >= 91) THEN FELTHAP = .;
   IF (FELTUNF >= 91) THEN FELTUNF = .;
   IF (FELTENJ >= 91) THEN FELTENJ = .;
   IF (FELTCRY >= 91) THEN FELTCRY = .;
   IF (FELTDISL >= 91) THEN FELTDISL = .;
   IF (FELTNOGO >= 91) THEN FELTNOGO = .;
   IF (AS11READ >= 91) THEN AS11READ = .;
   IF (NODRUGS >= 91) THEN NODRUGS = .;
   IF (CDCIGX >= 91) THEN CDCIGX = .;
   IF (CDALCX >= 91) THEN CDALCX = .;
   IF (CDSEDX >= 91) THEN CDSEDX = .;
   IF (CDTRANX >= 91) THEN CDTRANX = .;
   IF (CDSTMX >= 91) THEN CDSTMX = .;
   IF (CDANALX >= 91) THEN CDANALX = .;
   IF (CDMJX >= 91) THEN CDMJX = .;
   IF (CDINHX >= 91) THEN CDINHX = .;
   IF (CDCOCX >= 91) THEN CDCOCX = .;
   IF (CDHALLX >= 91) THEN CDHALLX = .;
   IF (CDHERX >= 91) THEN CDHERX = .;
   IF (CDOTHOPX >= 91) THEN CDOTHOPX = .;
   IF (CDNONEX >= 91) THEN CDNONEX = .;
   IF (EFFCIGX >= 91) THEN EFFCIGX = .;
   IF (EFFALCX >= 91) THEN EFFALCX = .;
   IF (EFFSEDX >= 91) THEN EFFSEDX = .;
   IF (EFFTRANX >= 91) THEN EFFTRANX = .;
   IF (EFFSTMX >= 91) THEN EFFSTMX = .;
   IF (EFFANALX >= 91) THEN EFFANALX = .;
   IF (EFFMJX >= 91) THEN EFFMJX = .;
   IF (EFFINHX >= 91) THEN EFFINHX = .;
   IF (EFFCOCX >= 91) THEN EFFCOCX = .;
   IF (EFFHALLX >= 91) THEN EFFHALLX = .;
   IF (EFFHERX >= 91) THEN EFFHERX = .;
   IF (EFFOTHOX >= 91) THEN EFFOTHOX = .;
   IF (EFFNONEX >= 91) THEN EFFNONEX = .;
   IF (UDAYCIGX >= 91) THEN UDAYCIGX = .;
   IF (UDAYALCX >= 91) THEN UDAYALCX = .;
   IF (UDAYSEDX >= 91) THEN UDAYSEDX = .;
   IF (UDAYTRAX >= 91) THEN UDAYTRAX = .;
   IF (UDAYSTMX >= 91) THEN UDAYSTMX = .;
   IF (UDAYANAX >= 91) THEN UDAYANAX = .;
   IF (UDAYMJX >= 91) THEN UDAYMJX = .;
   IF (UDAYINHX >= 91) THEN UDAYINHX = .;
   IF (UDAYCOCX >= 91) THEN UDAYCOCX = .;
   IF (UDAYHALX >= 91) THEN UDAYHALX = .;
   IF (UDAYHERX >= 91) THEN UDAYHERX = .;
   IF (UDAYOTHX >= 91) THEN UDAYOTHX = .;
   IF (UDAYNONX >= 91) THEN UDAYNONX = .;
   IF (DEPCIGX >= 91) THEN DEPCIGX = .;
   IF (DEPALCX >= 91) THEN DEPALCX = .;
   IF (DEPSEDX >= 91) THEN DEPSEDX = .;
   IF (DEPTRANX >= 91) THEN DEPTRANX = .;
   IF (DEPSTMX >= 91) THEN DEPSTMX = .;
   IF (DEPANALX >= 91) THEN DEPANALX = .;
   IF (DEPMJX >= 91) THEN DEPMJX = .;
   IF (DEPINHX >= 91) THEN DEPINHX = .;
   IF (DEPCOCX >= 91) THEN DEPCOCX = .;
   IF (DEPHALLX >= 91) THEN DEPHALLX = .;
   IF (DEPHERX >= 91) THEN DEPHERX = .;
   IF (DEPOTHOX >= 91) THEN DEPOTHOX = .;
   IF (DEPNONEX >= 91) THEN DEPNONEX = .;
   IF (WSCIGX >= 91) THEN WSCIGX = .;
   IF (WSALCX >= 91) THEN WSALCX = .;
   IF (WSSEDX >= 91) THEN WSSEDX = .;
   IF (WSTRANX >= 91) THEN WSTRANX = .;
   IF (WSSTMX >= 91) THEN WSSTMX = .;
   IF (WSANALX >= 91) THEN WSANALX = .;
   IF (WSMJX >= 91) THEN WSMJX = .;
   IF (WSINHX >= 91) THEN WSINHX = .;
   IF (WSCOCX >= 91) THEN WSCOCX = .;
   IF (WSHALLX >= 91) THEN WSHALLX = .;
   IF (WSHERX >= 91) THEN WSHERX = .;
   IF (WSOTHOPX >= 91) THEN WSOTHOPX = .;
   IF (WSNONEX >= 91) THEN WSNONEX = .;
   IF (NOBOOZYR >= 91) THEN NOBOOZYR = .;
   IF (ALCAGGR >= 91) THEN ALCAGGR = .;
   IF (ALCARGUM >= 91) THEN ALCARGUM = .;
   IF (ALCABSNT >= 91) THEN ALCABSNT = .;
   IF (ALCHIGH >= 91) THEN ALCHIGH = .;
   IF (ALCJOB >= 91) THEN ALCJOB = .;
   IF (ALCMATCD >= 91) THEN ALCMATCD = .;
   IF (ALCRELCD >= 91) THEN ALCRELCD = .;
   IF (ALCFRDCD >= 91) THEN ALCFRDCD = .;
   IF (ALCTOSS >= 91) THEN ALCTOSS = .;
   IF (ALCHOLIC >= 91) THEN ALCHOLIC = .;
   IF (ALCDRUNK >= 91) THEN ALCDRUNK = .;
   IF (ALCINTOX >= 91) THEN ALCINTOX = .;
   IF (ALCREM >= 91) THEN ALCREM = .;
   IF (ALCQUICK >= 91) THEN ALCQUICK = .;
   IF (ALCMORN >= 91) THEN ALCMORN = .;
   IF (ALCSHOOK >= 91) THEN ALCSHOOK = .;
   IF (ALCALONE >= 91) THEN ALCALONE = .;
   IF (ALCBRKPM >= 91) THEN ALCBRKPM = .;
   IF (AS13NONE >= 91) THEN AS13NONE = .;
   IF (DRDEPRSS >= 91) THEN DRDEPRSS = .;
   IF (DEPDRG1A >= 991) THEN DEPDRG1A = .;
   IF (DEPDRG2A >= 991) THEN DEPDRG2A = .;
   IF (DEPDRG3A >= 991) THEN DEPDRG3A = .;
   IF (DEPDRG4A >= 991) THEN DEPDRG4A = .;
   IF (DEPDRG5A >= 991) THEN DEPDRG5A = .;
   IF (DEPDRG6A >= 991) THEN DEPDRG6A = .;
   IF (DRARGUM >= 91) THEN DRARGUM = .;
   IF (ARGDRG1A >= 991) THEN ARGDRG1A = .;
   IF (ARGDRG2A >= 991) THEN ARGDRG2A = .;
   IF (ARGDRG3A >= 991) THEN ARGDRG3A = .;
   IF (ARGDRG4A >= 991) THEN ARGDRG4A = .;
   IF (ARGDRG5A >= 991) THEN ARGDRG5A = .;
   IF (ARGDRG6A >= 991) THEN ARGDRG6A = .;
   IF (DRTRBLE >= 91) THEN DRTRBLE = .;
   IF (TRBDRG1A >= 991) THEN TRBDRG1A = .;
   IF (TRBDRG2A >= 991) THEN TRBDRG2A = .;
   IF (TRBDRG3A >= 991) THEN TRBDRG3A = .;
   IF (TRBDRG4A >= 991) THEN TRBDRG4A = .;
   IF (TRBDRG5A >= 991) THEN TRBDRG5A = .;
   IF (TRBDRG6A >= 991) THEN TRBDRG6A = .;
   IF (DRDRIVE >= 91) THEN DRDRIVE = .;
   IF (DRVDRG1A >= 991) THEN DRVDRG1A = .;
   IF (DRVDRG2A >= 991) THEN DRVDRG2A = .;
   IF (DRVDRG3A >= 991) THEN DRVDRG3A = .;
   IF (DRVDRG4A >= 991) THEN DRVDRG4A = .;
   IF (DRVDRG5A >= 991) THEN DRVDRG5A = .;
   IF (DRVDRG6A >= 991) THEN DRVDRG6A = .;
   IF (DRNTRMB >= 91) THEN DRNTRMB = .;
   IF (NRMDRG1A >= 991) THEN NRMDRG1A = .;
   IF (NRMDRG2A >= 991) THEN NRMDRG2A = .;
   IF (NRMDRG3A >= 991) THEN NRMDRG3A = .;
   IF (NRMDRG4A >= 991) THEN NRMDRG4A = .;
   IF (NRMDRG5A >= 991) THEN NRMDRG5A = .;
   IF (NRMDRG6A >= 991) THEN NRMDRG6A = .;
   IF (DRALONE >= 91) THEN DRALONE = .;
   IF (ALNDRG1A >= 991) THEN ALNDRG1A = .;
   IF (ALNDRG2A >= 991) THEN ALNDRG2A = .;
   IF (ALNDRG3A >= 991) THEN ALNDRG3A = .;
   IF (ALNDRG4A >= 991) THEN ALNDRG4A = .;
   IF (ALNDRG5A >= 991) THEN ALNDRG5A = .;
   IF (ALNDRG6A >= 991) THEN ALNDRG6A = .;
   IF (DRANX >= 91) THEN DRANX = .;
   IF (ANXDRG1A >= 991) THEN ANXDRG1A = .;
   IF (ANXDRG2A >= 991) THEN ANXDRG2A = .;
   IF (ANXDRG3A >= 991) THEN ANXDRG3A = .;
   IF (ANXDRG4A >= 991) THEN ANXDRG4A = .;
   IF (ANXDRG5A >= 991) THEN ANXDRG5A = .;
   IF (ANXDRG6A >= 991) THEN ANXDRG6A = .;
   IF (DRHEALTH >= 91) THEN DRHEALTH = .;
   IF (HLTDRG1A >= 991) THEN HLTDRG1A = .;
   IF (HLTDRG2A >= 991) THEN HLTDRG2A = .;
   IF (HLTDRG3A >= 991) THEN HLTDRG3A = .;
   IF (HLTDRG4A >= 991) THEN HLTDRG4A = .;
   IF (HLTDRG5A >= 991) THEN HLTDRG5A = .;
   IF (HLTDRG6A >= 991) THEN HLTDRG6A = .;
   IF (DRNTHINK >= 91) THEN DRNTHINK = .;
   IF (NTKDRG1A >= 991) THEN NTKDRG1A = .;
   IF (NTKDRG2A >= 991) THEN NTKDRG2A = .;
   IF (NTKDRG3A >= 991) THEN NTKDRG3A = .;
   IF (NTKDRG4A >= 991) THEN NTKDRG4A = .;
   IF (NTKDRG5A >= 991) THEN NTKDRG5A = .;
   IF (NTKDRG6A >= 991) THEN NTKDRG6A = .;
   IF (DRMNYPRB >= 91) THEN DRMNYPRB = .;
   IF (MNYDRG1A >= 991) THEN MNYDRG1A = .;
   IF (MNYDRG2A >= 991) THEN MNYDRG2A = .;
   IF (MNYDRG3A >= 991) THEN MNYDRG3A = .;
   IF (MNYDRG4A >= 991) THEN MNYDRG4A = .;
   IF (MNYDRG5A >= 991) THEN MNYDRG5A = .;
   IF (MNYDRG6A >= 991) THEN MNYDRG6A = .;
   IF (DRUPSET >= 91) THEN DRUPSET = .;
   IF (UPSDRG1A >= 991) THEN UPSDRG1A = .;
   IF (UPSDRG2A >= 991) THEN UPSDRG2A = .;
   IF (UPSDRG3A >= 991) THEN UPSDRG3A = .;
   IF (UPSDRG4A >= 991) THEN UPSDRG4A = .;
   IF (UPSDRG5A >= 991) THEN UPSDRG5A = .;
   IF (UPSDRG6A >= 991) THEN UPSDRG6A = .;
   IF (DRLSWORK >= 91) THEN DRLSWORK = .;
   IF (LSWDRG1A >= 991) THEN LSWDRG1A = .;
   IF (LSWDRG2A >= 991) THEN LSWDRG2A = .;
   IF (LSWDRG3A >= 991) THEN LSWDRG3A = .;
   IF (LSWDRG4A >= 991) THEN LSWDRG4A = .;
   IF (LSWDRG5A >= 991) THEN LSWDRG5A = .;
   IF (LSWDRG6A >= 991) THEN LSWDRG6A = .;
   IF (DRSUSPIC >= 91) THEN DRSUSPIC = .;
   IF (SSPDRG1A >= 991) THEN SSPDRG1A = .;
   IF (SSPDRG2A >= 991) THEN SSPDRG2A = .;
   IF (SSPDRG3A >= 991) THEN SSPDRG3A = .;
   IF (SSPDRG4A >= 991) THEN SSPDRG4A = .;
   IF (SSPDRG5A >= 991) THEN SSPDRG5A = .;
   IF (SSPDRG6A >= 991) THEN SSPDRG6A = .;
   IF (DRTRBLAW >= 91) THEN DRTRBLAW = .;
   IF (LAWDRG1A >= 991) THEN LAWDRG1A = .;
   IF (LAWDRG2A >= 991) THEN LAWDRG2A = .;
   IF (LAWDRG3A >= 991) THEN LAWDRG3A = .;
   IF (LAWDRG4A >= 991) THEN LAWDRG4A = .;
   IF (LAWDRG5A >= 991) THEN LAWDRG5A = .;
   IF (LAWDRG6A >= 991) THEN LAWDRG6A = .;
   IF (DRNOTEAT >= 91) THEN DRNOTEAT = .;
   IF (NETDRG1A >= 991) THEN NETDRG1A = .;
   IF (NETDRG2A >= 991) THEN NETDRG2A = .;
   IF (NETDRG3A >= 991) THEN NETDRG3A = .;
   IF (NETDRG4A >= 991) THEN NETDRG4A = .;
   IF (NETDRG5A >= 991) THEN NETDRG5A = .;
   IF (NETDRG6A >= 991) THEN NETDRG6A = .;
   IF (DRCOPE >= 91) THEN DRCOPE = .;
   IF (CPEDRG1A >= 991) THEN CPEDRG1A = .;
   IF (CPEDRG2A >= 991) THEN CPEDRG2A = .;
   IF (CPEDRG3A >= 991) THEN CPEDRG3A = .;
   IF (CPEDRG4A >= 991) THEN CPEDRG4A = .;
   IF (CPEDRG5A >= 991) THEN CPEDRG5A = .;
   IF (CPEDRG6A >= 991) THEN CPEDRG6A = .;
   IF (DREMGMED >= 91) THEN DREMGMED = .;
   IF (EMDRG1A >= 991) THEN EMDRG1A = .;
   IF (EMDRG2A >= 991) THEN EMDRG2A = .;
   IF (EMDRG3A >= 991) THEN EMDRG3A = .;
   IF (EMDRG4A >= 991) THEN EMDRG4A = .;
   IF (EMDRG5A >= 991) THEN EMDRG5A = .;
   IF (EMDRG6A >= 991) THEN EMDRG6A = .;
   IF (AS14READ >= 91) THEN AS14READ = .;
   IF (HLPQTCIG >= 91) THEN HLPQTCIG = .;
   IF (HLPALCHO >= 91) THEN HLPALCHO = .;
   IF (HLPDRUSE >= 91) THEN HLPDRUSE = .;
   IF (TRTER >= 91) THEN TRTER = .;
   IF (TRTHOSP >= 91) THEN TRTHOSP = .;
   IF (TRTPDOC >= 91) THEN TRTPDOC = .;
   IF (TRTREH >= 91) THEN TRTREH = .;
   IF (TRTMHF >= 91) THEN TRTMHF = .;
   IF (TRTSHELP >= 91) THEN TRTSHELP = .;
   IF (TRTOTHER >= 91) THEN TRTOTHER = .;
   IF (TRTNONE >= 91) THEN TRTNONE = .;
   IF (TRTNEWA >= 91) THEN TRTNEWA = .;
   IF (TRTNEWB >= 91) THEN TRTNEWB = .;
   IF (TRTCALL >= 91) THEN TRTCALL = .;
   IF (TRTCALLO >= 91) THEN TRTCALLO = .;
   IF (TRTDRGYR >= 91) THEN TRTDRGYR = .;
   IF (TRTPRBYR >= 91) THEN TRTPRBYR = .;
   IF (RSKPKCIG >= 91) THEN RSKPKCIG = .;
   IF (RSKMJOCC >= 91) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 91) THEN RSKMJREG = .;
   IF (RKTRYPCP >= 91) THEN RKTRYPCP = .;
   IF (RKPCPREG >= 91) THEN RKPCPREG = .;
   IF (RKTRYHER >= 91) THEN RKTRYHER = .;
   IF (RKHERREG >= 91) THEN RKHERREG = .;
   IF (RKTRYCOC >= 91) THEN RKTRYCOC = .;
   IF (RKCOCOCC >= 91) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 91) THEN RKCOCREG = .;
   IF (RK2DRINK >= 91) THEN RK2DRINK = .;
   IF (RK5DRINK >= 91) THEN RK5DRINK = .;
   IF (RSKBINGE >= 91) THEN RSKBINGE = .;
   IF (BIRMON >= 91) THEN BIRMON = .;
   IF (MARITAL >= 91) THEN MARITAL = .;
   IF (NOMARR >= 91) THEN NOMARR = .;
   IF (WORKSTAT >= 91) THEN WORKSTAT = .;
   IF (PAYYR >= 91) THEN PAYYR = .;
   IF (PAYMO >= 91) THEN PAYMO = .;
   IF (ROCCUP1 >= 91) THEN ROCCUP1 = .;
   IF (BUSINES1 >= 91) THEN BUSINES1 = .;
   IF (NO5JOB >= 91) THEN NO5JOB = .;
   IF (CWE >= 91) THEN CWE = .;
   IF (FULLPART >= 91) THEN FULLPART = .;
   IF (CWEOCC1 >= 91) THEN CWEOCC1 = .;
   IF (CWEBUS1 >= 91) THEN CWEBUS1 = .;
   IF (EDUC >= 91) THEN EDUC = .;
   IF (STUDENT >= 91) THEN STUDENT = .;
   IF (SCHDAYS >= 91) THEN SCHDAYS = .;
   IF (SKIPPED >= 91) THEN SKIPPED = .;
   IF (WORKDAYS >= 91) THEN WORKDAYS = .;
   IF (WORKBLAH >= 91) THEN WORKBLAH = .;
   IF (MILES >= 99991) THEN MILES = .;
   IF (ACCID >= 91) THEN ACCID = .;
   IF (NOCHILD >= 91) THEN NOCHILD = .;
   IF (TOTPEOP >= 91) THEN TOTPEOP = .;
   IF (MOTHER >= 91) THEN MOTHER = .;
   IF (FATHER >= 91) THEN FATHER = .;
   IF (SPOUSE >= 91) THEN SPOUSE = .;
   IF (INLAW >= 91) THEN INLAW = .;
   IF (OWNCHILD >= 91) THEN OWNCHILD = .;
   IF (STEPCHLD >= 91) THEN STEPCHLD = .;
   IF (BROSIS >= 91) THEN BROSIS = .;
   IF (OTHREL >= 91) THEN OTHREL = .;
   IF (FRIENDS >= 91) THEN FRIENDS = .;
   IF (OTHERNON >= 91) THEN OTHERNON = .;
   IF (SERVICE >= 91) THEN SERVICE = .;
   IF (MILSTAT >= 91) THEN MILSTAT = .;
   IF (MILYR1A >= 91) THEN MILYR1A = .;
   IF (MILYR2A >= 91) THEN MILYR2A = .;
   IF (MILYR3A >= 91) THEN MILYR3A = .;
   IF (MILYR4A >= 91) THEN MILYR4A = .;
   IF (MILYR5A >= 91) THEN MILYR5A = .;
   IF (MILYR6A >= 91) THEN MILYR6A = .;
   IF (YRENTS >= 91) THEN YRENTS = .;
   IF (VIETNAM >= 91) THEN VIETNAM = .;
   IF (DORM >= 91) THEN DORM = .;
   IF (MILBASE >= 91) THEN MILBASE = .;
   IF (HOSP >= 91) THEN HOSP = .;
   IF (TELNO >= 91) THEN TELNO = .;
   IF (MOVES >= 91) THEN MOVES = .;
   IF (INCOME >= 91) THEN INCOME = .;
   IF (PARQ >= 91) THEN PARQ = .;
   IF (UNDINT >= 91) THEN UNDINT = .;
   IF (COOPINT >= 91) THEN COOPINT = .;
   IF (PRIVACY >= 91) THEN PRIVACY = .;
   IF (PPRES >= 91) THEN PPRES = .;
   IF (SPRES >= 91) THEN SPRES = .;
   IF (PARPRES >= 91) THEN PARPRES = .;
   IF (OARPRES >= 91) THEN OARPRES = .;
   IF (OAPRES >= 91) THEN OAPRES = .;
   IF (CPRES >= 91) THEN CPRES = .;
   IF (OPRES >= 91) THEN OPRES = .;
   IF (IIHOIND >= 9) THEN IIHOIND = .;
   IF (IRHOGRP >= 91) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 91) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 >= 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 91) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRNRC >= 9) THEN IRTRNRC = .;
   IF (IRSTMRC >= 9) THEN IRSTMRC = .;
   IF (IRANLRC >= 9) THEN IRANLRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IRINHRC >= 9) THEN IRINHRC = .;
   IF (IRHALRC >= 9) THEN IRHALRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
   IF (IRALCFQ >= 9) THEN IRALCFQ = .;
   IF (IRMJFQ >= 10) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 9) THEN IRCOCFQ = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CIGTRY cigtry. CIG5PK cig5pk. CIGREC cigrec.
         AVCIG avcig. CIGINT cigint. CIGTIME cigtime.
         CIGAGE cigage. CIGYRS cigyrs. PACKS packs.
         OTHTOB othtob. ADDALC addalc. ADDMJ addmj.
         ADDSED addsed. ADDTRAN addtran. ADDAMP addamp.
         ADDCOC addcoc. ADDLSD addlsd. ADDHER addher.
         ADDCIG addcig. ADDNONE addnone. ADDALL addall.
         ALCTRY alctry. ALCREC alcrec. ALCPREF alcpref.
         ALCDAYS alcdays. NODR30A nodr30a. MODR30A modr30a.
         MODR30DY modr30dy. DR5DAY dr5day. ALCAGE alcage.
         ALCPAT alcpat. DRUNKYR drunkyr. ALCSED alcsed.
         ALCTRAN alctran. ALCSTM alcstm. ALCANAL alcanal.
         ALCMJ alcmj. ALCINH alcinh. ALCCOC alccoc.
         ALCHAL alchal. ALCOPT alcopt. ALCNONE alcnone.
         NOSEDAT nosedat. BUTISOL butisol. BUTICAPS buticaps.
         AMYTAL amytal. ESKABARB eskabarb. LUMINAL luminal.
         MEBARAL mebaral. AMOBARB amobarb. PHENOBAR phenobar.
         ALURATE alurate. PLACIDYL placidyl. DORIDEN doriden.
         NOLUDAR noludar. SOPOR sopor. QUAALUDE quaalude.
         PAREST parest. NOCTEC noctec. METHAQ methaq.
         CHHYD chhyd. NEMBUTAL nembutal. CARBTAL carbtal.
         SECONAL seconal. TUINAL tuinal. PENTOB pentob.
         SECOB secob. DALMANE dalmane. SEDDKNAM seddknam.
         SEDOTH sedoth. SEDNEWA sednewa. SEDNEWB sednewb.
         SEDNEWC sednewc. SEDAGE sedage. SEDTOT sedtot.
         SEDREC sedrec. SEDALC sedalc. SEDTR sedtr.
         SEDST sedst. SEDAN sedan. SEDMJ sedmj.
         SEDINH sedinh. SEDCOC sedcoc. SEDHAL sedhal.
         SEDOPT sedopt. SEDNONE sednone. AS3READ as3read.
         NOTRANQ notranq. VALIUM valium. LIBRIUM librium.
         LIBTAB libtab. SKLY skly. SERAX serax.
         TRANXENE tranxene. ATIVAN ativan. VERSTRAN verstran.
         MEPRSPAN meprspan. MILTOWN miltown. EQUANIL equanil.
         MEPROB meprob. VISTAR vistar. ATARAX atarax.
         BENADRYL benadryl. XANAX xanax. TRDKNAM trdknam.
         TROTH troth. TRNEWA trnewa. TRNEWB trnewb.
         TRNEWC trnewc. TRANAGE tranage. TRANTOT trantot.
         TRANREC tranrec. TRALC tralc. TRSED trsed.
         TRSTM trstm. TRANAL tranal. TRMJ trmj.
         TRINH trinh. TRCOC trcoc. TRHAL trhal.
         TROPT tropt. TRNONE trnone. AS4READ as4read.
         NOSTIMS nostims. DEXED dexed. DEXAMYL dexamyl.
         ESKAT eskat. BENZ benz. BIPHET biphet.
         DESOXYN desoxyn. DETAMP detamp. METHI methi.
         OBLA obla. TENUATE tenuate. TEPANIL tepanil.
         DIDREX didrex. PLEGINE plegine. PRELUDIN preludin.
         PRESATE presate. IONAMIN ionamin. PONDIMIN pondimin.
         VORANIL voranil. SANOREX sanorex. RITALIN ritalin.
         CYLERT cylert. STMDKNAM stmdknam. STIMOR stimor.
         STIMNEWA stimnewa. STIMNEWB stimnewb. STIMNEWC stimnewc.
         STIMAGE stimage. STIMTOT stimtot. STIMREC stimrec.
         STALC stalc. STSED stsed. STTRAN sttran.
         STANAL stanal. STMJ stmj. STINH stinh.
         STCOC stcoc. STHAL sthal. STOPT stopt.
         STNONE stnone. AS5READ as5read. ANALNONE analnone.
         DARVON darvon. DOLENE dolene. SK65A sk65a.
         PROPOXY propoxy. LERITINE leritine. LEVODRO levodro.
         PERCODAN percodan. DEMEROL demerol. DILAUD dilaud.
         TYLCOD tylcod. CODEINE codeine. DOLOP dolop.
         WESTOD westod. METHDON methdon. TALWIN talwin.
         ANLDKNAM anldknam. ANALOTH analoth. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNEWC analnewc. ANALAGE analage.
         ANALTOT analtot. ANALREC analrec. ANLALC anlalc.
         ANLSED anlsed. ANLTRAN anltran. ANLSTM anlstm.
         ANLMJ anlmj. ANLINH anlinh. ANLCOC anlcoc.
         ANLHAL anlhal. ANLOPT anlopt. ANLNONE anlnone.
         MJOPP mjopp. MJAGE mjage. MJTOT mjtot.
         MJREC mjrec. MJDAY30A mjday30a. MJAV30A mjav30a.
         MJAMT30A mjamt30a. MJDOL mjdol. MJALC30A mjalc30a.
         MJYRFREQ mjyrfreq. MJALC mjalc. MJSED mjsed.
         MJTRAN mjtran. MJSTM mjstm. MJANAL mjanal.
         MJINH mjinh. MJCOC mjcoc. MJHAL mjhal.
         MJOPT mjopt. MJNONE mjnone. AS7READ as7read.
         INHNONE inhnone. GAS gas. SPPAINT sppaint.
         AEROS aeros. GLUE glue. SOLVENT solvent.
         AMYLNIT amylnit. ETHER ether. NITOXID nitoxid.
         CLEFLU cleflu. OTHINHL othinhl. INHNEWA inhnewa.
         GAS30A gas30a. SPPAN30A sppan30a. AEROS30A aeros30a.
         GLUE30A glue30a. SOLVN30A solvn30a. AMLNT30A amlnt30a.
         ETHER30A ether30a. NOX30A nox30a. CLFL30A clfl30a.
         INHOT30A inhot30a. INH30NO inh30no. INHTOT inhtot.
         INHREC inhrec. INHDY30A inhdy30a. INHEFF inheff.
         INHPO inhpo. INHQNC inhqnc. INHANSY inhansy.
         AS8READ as8read. COCOPP cocopp. COCAGE cocage.
         COCTOT coctot. COCREC cocrec. COCUS30A cocus30a.
         COCAM30A cocam30a. COCBUCK cocbuck. COC30ALC coc30alc.
         COCYRFRQ cocyrfrq. COCALC cocalc. COCSED cocsed.
         COCTRAN coctran. COCSTM cocstm. COCANAL cocanal.
         COCMJ cocmj. COCINH cocinh. COCHAL cochal.
         COCOPT cocopt. COCNONE cocnone. COCSNIFX cocsnifx.
         COCSWALX cocswalx. COCIVX cocivx. FREEBASX freebasx.
         COCOTHX cocothx. AS9READ as9read. HALLQCL hallqcl.
         HALLOPP hallopp. HALLAGE hallage. HALLTOT halltot.
         HALLREC hallrec. HAL30USE hal30use. LSD lsd.
         PEYOTE peyote. MESC mesc. PSILCY psilcy.
         PCP pcp. HALLOTH halloth. HALNEWA halnewa.
         HALNEWB halnewb. PCPREC pcprec. PCPFLASH pcpflash.
         PCPSENSE pcpsense. PCPFEELV pcpfeelv. PCPACTV pcpactv.
         PCPOTH pcpoth. PCPNORCT pcpnorct. PCPNEWA pcpnewa.
         PCPNEWB pcpnewb. AS10READ as10read. HEROPP heropp.
         HERAGE herage. HERTOT hertot. HERREC herrec.
         HER30USE her30use. HERNEEDL herneedl. HIGHBP highbp.
         BPMED bpmed. WALKPAIN walkpain. TIMEPAIN timepain.
         UPSHOR upshor. ASTHMA asthma. TRPSYCH trpsych.
         HEART heart. FLU flu. ALLERG allerg.
         HOSPYR hospyr. SOREYR soreyr. RUNNYYR runnyyr.
         COUGHYR coughyr. PHLEGMYR phlegmyr. HEALTHYR healthyr.
         FELTGOOD feltgood. FELTMIND feltmind. FELTDEP feltdep.
         FELTEFF felteff. FELTHOPE felthope. FELTSLEP feltslep.
         FELTHAP felthap. FELTUNF feltunf. FELTENJ feltenj.
         FELTCRY feltcry. FELTDISL feltdisl. FELTNOGO feltnogo.
         AS11READ as11read. NODRUGS nodrugs. CDCIGX cdcigx.
         CDALCX cdalcx. CDSEDX cdsedx. CDTRANX cdtranx.
         CDSTMX cdstmx. CDANALX cdanalx. CDMJX cdmjx.
         CDINHX cdinhx. CDCOCX cdcocx. CDHALLX cdhallx.
         CDHERX cdherx. CDOTHOPX cdothopx. CDNONEX cdnonex.
         EFFCIGX effcigx. EFFALCX effalcx. EFFSEDX effsedx.
         EFFTRANX efftranx. EFFSTMX effstmx. EFFANALX effanalx.
         EFFMJX effmjx. EFFINHX effinhx. EFFCOCX effcocx.
         EFFHALLX effhallx. EFFHERX effherx. EFFOTHOX effothox.
         EFFNONEX effnonex. UDAYCIGX udaycigx. UDAYALCX udayalcx.
         UDAYSEDX udaysedx. UDAYTRAX udaytrax. UDAYSTMX udaystmx.
         UDAYANAX udayanax. UDAYMJX udaymjx. UDAYINHX udayinhx.
         UDAYCOCX udaycocx. UDAYHALX udayhalx. UDAYHERX udayherx.
         UDAYOTHX udayothx. UDAYNONX udaynonx. DEPCIGX depcigx.
         DEPALCX depalcx. DEPSEDX depsedx. DEPTRANX deptranx.
         DEPSTMX depstmx. DEPANALX depanalx. DEPMJX depmjx.
         DEPINHX depinhx. DEPCOCX depcocx. DEPHALLX dephallx.
         DEPHERX depherx. DEPOTHOX depothox. DEPNONEX depnonex.
         WSCIGX wscigx. WSALCX wsalcx. WSSEDX wssedx.
         WSTRANX wstranx. WSSTMX wsstmx. WSANALX wsanalx.
         WSMJX wsmjx. WSINHX wsinhx. WSCOCX wscocx.
         WSHALLX wshallx. WSHERX wsherx. WSOTHOPX wsothopx.
         WSNONEX wsnonex. NOBOOZYR noboozyr. ALCAGGR alcaggr.
         ALCARGUM alcargum. ALCABSNT alcabsnt. ALCHIGH alchigh.
         ALCJOB alcjob. ALCMATCD alcmatcd. ALCRELCD alcrelcd.
         ALCFRDCD alcfrdcd. ALCTOSS alctoss. ALCHOLIC alcholic.
         ALCDRUNK alcdrunk. ALCINTOX alcintox. ALCREM alcrem.
         ALCQUICK alcquick. ALCMORN alcmorn. ALCSHOOK alcshook.
         ALCALONE alcalone. ALCBRKPM alcbrkpm. AS13NONE as13none.
         DRDEPRSS drdeprss. DEPDRG1A depdrg1a. DEPDRG2A depdrg2a.
         DEPDRG3A depdrg3a. DEPDRG4A depdrg4a. DEPDRG5A depdrg5a.
         DEPDRG6A depdrg6a. DRARGUM drargum. ARGDRG1A argdrg1a.
         ARGDRG2A argdrg2a. ARGDRG3A argdrg3a. ARGDRG4A argdrg4a.
         ARGDRG5A argdrg5a. ARGDRG6A argdrg6a. DRTRBLE drtrble.
         TRBDRG1A trbdrg1a. TRBDRG2A trbdrg2a. TRBDRG3A trbdrg3a.
         TRBDRG4A trbdrg4a. TRBDRG5A trbdrg5a. TRBDRG6A trbdrg6a.
         DRDRIVE drdrive. DRVDRG1A drvdrg1a. DRVDRG2A drvdrg2a.
         DRVDRG3A drvdrg3a. DRVDRG4A drvdrg4a. DRVDRG5A drvdrg5a.
         DRVDRG6A drvdrg6a. DRNTRMB drntrmb. NRMDRG1A nrmdrg1a.
         NRMDRG2A nrmdrg2a. NRMDRG3A nrmdrg3a. NRMDRG4A nrmdrg4a.
         NRMDRG5A nrmdrg5a. NRMDRG6A nrmdrg6a. DRALONE dralone.
         ALNDRG1A alndrg1a. ALNDRG2A alndrg2a. ALNDRG3A alndrg3a.
         ALNDRG4A alndrg4a. ALNDRG5A alndrg5a. ALNDRG6A alndrg6a.
         DRANX dranx. ANXDRG1A anxdrg1a. ANXDRG2A anxdrg2a.
         ANXDRG3A anxdrg3a. ANXDRG4A anxdrg4a. ANXDRG5A anxdrg5a.
         ANXDRG6A anxdrg6a. DRHEALTH drhealth. HLTDRG1A hltdrg1a.
         HLTDRG2A hltdrg2a. HLTDRG3A hltdrg3a. HLTDRG4A hltdrg4a.
         HLTDRG5A hltdrg5a. HLTDRG6A hltdrg6a. DRNTHINK drnthink.
         NTKDRG1A ntkdrg1a. NTKDRG2A ntkdrg2a. NTKDRG3A ntkdrg3a.
         NTKDRG4A ntkdrg4a. NTKDRG5A ntkdrg5a. NTKDRG6A ntkdrg6a.
         DRMNYPRB drmnyprb. MNYDRG1A mnydrg1a. MNYDRG2A mnydrg2a.
         MNYDRG3A mnydrg3a. MNYDRG4A mnydrg4a. MNYDRG5A mnydrg5a.
         MNYDRG6A mnydrg6a. DRUPSET drupset. UPSDRG1A upsdrg1a.
         UPSDRG2A upsdrg2a. UPSDRG3A upsdrg3a. UPSDRG4A upsdrg4a.
         UPSDRG5A upsdrg5a. UPSDRG6A upsdrg6a. DRLSWORK drlswork.
         LSWDRG1A lswdrg1a. LSWDRG2A lswdrg2a. LSWDRG3A lswdrg3a.
         LSWDRG4A lswdrg4a. LSWDRG5A lswdrg5a. LSWDRG6A lswdrg6a.
         DRSUSPIC drsuspic. SSPDRG1A sspdrg1a. SSPDRG2A sspdrg2a.
         SSPDRG3A sspdrg3a. SSPDRG4A sspdrg4a. SSPDRG5A sspdrg5a.
         SSPDRG6A sspdrg6a. DRTRBLAW drtrblaw. LAWDRG1A lawdrg1a.
         LAWDRG2A lawdrg2a. LAWDRG3A lawdrg3a. LAWDRG4A lawdrg4a.
         LAWDRG5A lawdrg5a. LAWDRG6A lawdrg6a. DRNOTEAT drnoteat.
         NETDRG1A netdrg1a. NETDRG2A netdrg2a. NETDRG3A netdrg3a.
         NETDRG4A netdrg4a. NETDRG5A netdrg5a. NETDRG6A netdrg6a.
         DRCOPE drcope. CPEDRG1A cpedrg1a. CPEDRG2A cpedrg2a.
         CPEDRG3A cpedrg3a. CPEDRG4A cpedrg4a. CPEDRG5A cpedrg5a.
         CPEDRG6A cpedrg6a. DREMGMED dremgmed. EMDRG1A emdrg1a.
         EMDRG2A emdrg2a. EMDRG3A emdrg3a. EMDRG4A emdrg4a.
         EMDRG5A emdrg5a. EMDRG6A emdrg6a. AS14READ as14read.
         HLPQTCIG hlpqtcig. HLPALCHO hlpalcho. HLPDRUSE hlpdruse.
         TRTER trter. TRTHOSP trthosp. TRTPDOC trtpdoc.
         TRTREH trtreh. TRTMHF trtmhf. TRTSHELP trtshelp.
         TRTOTHER trtother. TRTNONE trtnone. TRTNEWA trtnewa.
         TRTNEWB trtnewb. TRTCALL trtcall. TRTCALLO trtcallo.
         TRTDRGYR trtdrgyr. TRTPRBYR trtprbyr. RSKPKCIG rskpkcig.
         RSKMJOCC rskmjocc. RSKMJREG rskmjreg. RKTRYPCP rktrypcp.
         RKPCPREG rkpcpreg. RKTRYHER rktryher. RKHERREG rkherreg.
         RKTRYCOC rktrycoc. RKCOCOCC rkcococc. RKCOCREG rkcocreg.
         RK2DRINK rk2drink. RK5DRINK rk5drink. RSKBINGE rskbinge.
         SEX sex. BIRMON birmon. MARITAL marital.
         NOMARR nomarr. WORKSTAT workstat. PAYYR payyr.
         PAYMO paymo. ROCCUP1 roccup1f. BUSINES1 businesf.
         NO5JOB no5job. CWE cwe. FULLPART fullpart.
         CWEOCC1 cweocc1f. CWEBUS1 cwebus1f. EDUC educ.
         STUDENT student. SCHDAYS schdays. SKIPPED skipped.
         WORKDAYS workdays. WORKBLAH workblah. MILES miles.
         ACCID accid. NOCHILD nochild. TOTPEOP totpeop.
         MOTHER mother. FATHER father. SPOUSE spouse.
         INLAW inlaw. OWNCHILD ownchild. STEPCHLD stepchld.
         BROSIS brosis. OTHREL othrel. FRIENDS friends.
         OTHERNON othernon. SERVICE service. MILSTAT milstat.
         MILYR1A milyr1a. MILYR2A milyr2a. MILYR3A milyr3a.
         MILYR4A milyr4a. MILYR5A milyr5a. MILYR6A milyr6a.
         YRENTS yrents. VIETNAM vietnam. DORM dorm.
         MILBASE milbase. HOSP hosp. TELNO telno.
         MOVES moves. INCOME income. EIIDATE eiidate.
         INTMONTH intmonth. PARQ parq. UNDINT undint.
         COOPINT coopint. PRIVACY privacy. PPRES ppres.
         SPRES spres. PARPRES parpres. OARPRES oarpres.
         OAPRES oapres. CPRES cpres. OPRES opres.
         POPDEN popden. REGION region. DIVISION division.
         EIBDATE eibdate. IIAGE iiage. IRSEX irsex.
         IISEX iisex. IRRACE irrace. IIRACE iirace.
         IRHOIND irhoind. IIHOIND iihoind. IRHOGRP irhogrp.
         IIHOGRP iihogrp. IRHOGRP2 irhogrpf. IIHOGRP2 iihogrpf.
         IRMARIT irmarit. IIMARIT iimarit. IREDUC ireduc.
         IIEDUC iieduc. IRWORKST irworkst. IIWORKST iiworkst.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRTRNRC irtrnrc.
         IITRNRC iitrnrc. IRSTMRC irstmrc. IISTMRC iistmrc.
         IRANLRC iranlrc. IIANLRC iianlrc. IRCIGRC ircigrc.
         IICIGRC iicigrc. IRINHRC irinhrc. IIINHRC iiinhrc.
         IRHALRC irhalrc. IIHALRC iihalrc. IRHERRC irherrc.
         IIHERRC iiherrc. IRPCPRC irpcprc. IIPCPRC iipcprc.
         IRALCFQ iralcfq. IIALCFQ iialcfq. IRMJFQ irmjfq.
         IIMJFQ iimjfq. IRCOCFQ ircocfq. IICOCFQ iicocfq.
         CATAGE catage. CATAG2 catag2ff. RACE race.
         EDUCCAT2 educcatf. EMPSTAT2 empstatf. CIGFLAG cigflag.
         CIGYR cigyr. CIGMON cigmon. ALCFLAG alcflag.
         ALCYR alcyr. ALCMON alcmon. SEDFLAG sedflag.
         SEDYR sedyr. SEDMON sedmon. TRQFLAG trqflag.
         TRQYR trqyr. TRQMON trqmon. STMFLAG stmflag.
         STMYR stmyr. STMMON stmmon. ANLFLAG anlflag.
         ANLYR anlyr. ANLMON anlmon. MRJFLAG mrjflag.
         MRJYR mrjyr. MRJMON mrjmon. INHFLAG inhflag.
         INHYR inhyr. INHMON inhmon. COCFLAG cocflag.
         COCYR cocyr. COCMON cocmon. HALFLAG halflag.
         HALYR halyr. HALMON halmon. PCPFLAG pcpflag.
         PCPYR pcpyr. PCPMON pcpmon. HERFLAG herflag.
         HERYR heryr. HERMON hermon. PSYFLAG2 psyflagf.
         PSYYR2 psyyr2ff. PSYMON2 psymon2f. SUMFLAG sumflag.
         SUMYR sumyr. SUMMON summon. MJOFLAG mjoflag.
         MJOYR2 mjoyr2ff. MJOMON2 mjomon2f. IEMFLAG iemflag.
         IEMYR iemyr. IEMMON iemmon. ALCDLYF alcdlyf.
         ALCWKF alcwkf. ALCMONF alcmonf. ALCOCCF alcoccf.
         ALCYRF alcyrf. MRJDLYF mrjdlyf. MRJWKF mrjwkf.
         MRJMONF mrjmonf. MRJOCCF mrjoccf. MRJYRF mrjyrf.
         COCDLYF cocdlyf. COCWKF cocwkf. COCMONF cocmonf.
         COCOCCF cococcf. COCYRF cocyrf.  ;
*/

RUN ;
